(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    179652,       4641]
NotebookOptionsPosition[    171812,       4393]
NotebookOutlinePosition[    172318,       4413]
CellTagsIndexPosition[    172275,       4410]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Inverse Functions", "Title",
 CellChangeTimes->{{3.5351298689722958`*^9, 3.5351298741655397`*^9}}],

Cell["", "Subtitle",
 CellChangeTimes->{
  3.535130843110998*^9, {3.5351479238651323`*^9, 3.535147924844632*^9}, {
   3.535147955573587*^9, 3.535147961866239*^9}}],

Cell[TextData[{
 "It is suggested that you make a copy of this worksheet before you begin, so \
that you can modify the commands given when doing the exercises without loss \
of information. \nIf you wish to evaluate a cell, just click on the cell, \
choose ",
 StyleBox["Evaluation",
  FontSlant->"Italic"],
 " from the menu above and choose ",
 StyleBox["Evaluate Cells",
  FontSlant->"Italic"],
 ". \nTo get help on the use of a command or definition of a function, choose \
",
 StyleBox["Help",
  FontSlant->"Italic"],
 " from the menu above and click on ",
 StyleBox["Documentation Center",
  FontSlant->"Italic"],
 ". Enter the name of the command or function in the search field. \nFor this \
worksheet you should familiarize yourself with  the ",
 StyleBox["Plot",
  FontSlant->"Italic"],
 " command and its options, the S",
 StyleBox["olve, Simplify ",
  FontSlant->"Italic"],
 "and   ",
 StyleBox["Show ",
  FontSlant->"Italic"],
 "commands  and the topic  ",
 StyleBox["Differentiation",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.53514796994821*^9, 3.535147984888722*^9}, {
  3.535148027879974*^9, 3.535148170156666*^9}, {3.535148298336585*^9, 
  3.535148432819345*^9}, {3.535148487994687*^9, 3.535148499471084*^9}, {
  3.535148529989725*^9, 3.535148609536529*^9}, {3.535155727288941*^9, 
  3.535155743420033*^9}, {3.5351630269539957`*^9, 3.535163035934023*^9}, {
  3.535231053124167*^9, 3.535231078871468*^9}, {3.535231124575679*^9, 
  3.535231125180422*^9}}],

Cell[CellGroupData[{

Cell["One-To-One Functions", "Section",
 CellChangeTimes->{{3.5351298930134583`*^9, 3.535129897827978*^9}, {
  3.53513084846397*^9, 3.535130861526533*^9}, {3.535132760727837*^9, 
  3.535132779513608*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Definition of a  one-to-one function",
  FontColor->GrayLevel[0]],
 "."
}], "Subsection",
 CellGroupingRules->{"SectionGrouping", Inherited},
 CellChangeTimes->{{3.5351299111324377`*^9, 3.535129923722947*^9}, {
   3.535130803602477*^9, 3.5351308081934233`*^9}, {3.535130868997519*^9, 
   3.535130949816081*^9}, 3.535131083024949*^9, {3.535131122943171*^9, 
   3.53513129959606*^9}, {3.535131351512273*^9, 3.5351314474641123`*^9}, {
   3.535133247262513*^9, 3.535133270609796*^9}, 3.5351375764660473`*^9, {
   3.535137639868877*^9, 3.535137645986559*^9}, {3.53513768625595*^9, 
   3.5351377024731197`*^9}}],

Cell[TextData[{
 StyleBox["A function with equation ",
  FontWeight->"Plain"],
 "y=f(x) is a ",
 StyleBox["one-to-one",
  FontWeight->"Bold"],
 StyleBox[" if every y-value  appears at most  once on the graph of the \
function. \nThis translates to an ",
  FontWeight->"Plain"],
 StyleBox["algebraic statement",
  FontWeight->"Bold"],
 StyleBox[" of the following form: f is a one-to-one function if \nwhenever \
f(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], ")"}], " ", "=", " ", "f"}], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["x", "2"], ")"}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", then ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], "=", " ", 
    RowBox[{
     SubscriptBox["x", "2"], "."}]}], TraditionalForm]],
  FontWeight->"Plain"],
 "\n",
 StyleBox["It also translates to a ",
  FontWeight->"Plain"],
 StyleBox["geometric statement",
  FontWeight->"Bold"],
 StyleBox[" of the form:\nA function is one-to-one if every horizontal line \
cuts the graph at most once. \nThis allows us to \"check\" geometrically if a \
function is one-to-one using the horizontal line test described below.",
  FontWeight->"Plain"]
}], "Text",
 CellGroupingRules->"NormalGrouping",
 CellChangeTimes->{{3.5351299111324377`*^9, 3.535129923722947*^9}, {
   3.535130803602477*^9, 3.5351308081934233`*^9}, {3.535130868997519*^9, 
   3.535130949816081*^9}, 3.535131083024949*^9, {3.535131122943171*^9, 
   3.53513129959606*^9}, {3.535131351512273*^9, 3.5351314474641123`*^9}, {
   3.535133247262513*^9, 3.535133270609796*^9}, 3.5351375764660473`*^9, {
   3.535137639868877*^9, 3.535137645986559*^9}, {3.5351379087333508`*^9, 
   3.5351379234347267`*^9}, {3.535142968101269*^9, 3.535142974904825*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Checking if a function is one-to-one.",
 FontColor->GrayLevel[0]]], "Subsection",
 CellGroupingRules->{"SectionGrouping", Inherited},
 CellChangeTimes->{{3.53512992993111*^9, 3.535129935537665*^9}, {
  3.535130811761403*^9, 3.535130831319848*^9}, {3.535130960327834*^9, 
  3.535130979654214*^9}, {3.53513145944899*^9, 3.5351315188111973`*^9}, {
  3.5351377981122847`*^9, 3.535137818504463*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Horizontal Line Test : ",
  FontColor->RGBColor[
   0.7843137254901961, 0.4470588235294118, 0.07058823529411765]],
 " ",
 StyleBox["To check if a function is one-to-one, we check if  if every \
horizontal line cuts the graph at most once. If so, we can conclude that a \
function is one-to-one.",
  FontColor->GrayLevel[0]]
}], "Subsubsection",
 CellChangeTimes->{{3.53512992993111*^9, 3.535129935537665*^9}, {
   3.535130811761403*^9, 3.535130831319848*^9}, {3.535130960327834*^9, 
   3.535130979654214*^9}, {3.53513145944899*^9, 3.5351315188111973`*^9}, {
   3.5351377981122847`*^9, 3.535137818504463*^9}, 3.535138760733552*^9, 
   3.53514484320017*^9, {3.535144883943149*^9, 3.5351448980355043`*^9}}],

Cell[TextData[{
 "Here we consider the function f(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", "x"}], "+", "1"}], 
    RowBox[{"x", "-", "3"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  We will graph the function and some horizontal lines, checking that they \
 cut through the graph exactly once.  We define a function using := . We plot \
using the Plot command. To evaluate a cell, you click on the cell and choose \
Evaluate Cells from the Evaluation menu above. "
}], "Text",
 CellChangeTimes->{{3.535129945593539*^9, 3.535129965863564*^9}, {
  3.535130021147892*^9, 3.535130021220055*^9}, {3.535130765308836*^9, 
  3.535130790778411*^9}, {3.5351309841263113`*^9, 3.535131053929586*^9}, {
  3.535131633738145*^9, 3.535131635189096*^9}, {3.535131691843061*^9, 
  3.535131703939496*^9}, {3.535131777092873*^9, 3.53513183850274*^9}, {
  3.5351318714227123`*^9, 3.535131873404443*^9}, {3.535131923163294*^9, 
  3.53513196690235*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", "x"}], "+", "1"}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"x", "-", "3"}], ")"}]}]}]], "Input",
 CellChangeTimes->{
  3.535131764952981*^9, {3.535139634109572*^9, 3.535139648292879*^9}, {
   3.535139788163713*^9, 3.5351397930752783`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", 
     RowBox[{"-", "5"}], ",", " ", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.535132019766466*^9, 3.5351320660181513`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVynk81PkfwPG5cucaI7nPMLQ5CvUrn29FKhWhSXLfrC1yLD/XVo5Irkq5
CpVCEXogtN83Ci3Zch/rKJpxM+57fvv74/V4/vNScL5u4UYiEAiZ//Z/w1nn
FzgcKhjRSBscDhsxQ8WXB7aoEPhXiUTODhtdEB5erVynAkHbcAFts5H8Yd/t
64tU4Ikv6orYYKP6+FSeESYVPrDvXl1fYiOeX3pk4QsVSk65Xfw+wUYPAhxN
/8ikQqVHv2VYBxsVEf2fE/Sp4DNozd//go12uZno7LUThVt20Vn9hmxE7f3k
k5ciAgYNQySrvnlk0ZDhov6XMCjd+kfTxncehc4d80keFQJue/f1yrk5VPV7
hneJmSCIxVnInSbOoQupl+R30gWgkrmnrmZ2Bplkf7hwepoP7uGWk8f/nkb5
TSHd/ld5ob1YbiGkdArZRz2g/f2KG4g/7o/auU+iCEdyMT+VC4TGRHv/IzWB
CPvl8JPRFPC7lXOtGmeh/rvpsUVdJNBQX7hCpzORNJ9nwdIJIsyNPJ3vSxlD
vx6i7xqQ5uAbXuuJqWU/kIv+0KuGhk2803RbW7xsBNGDj3CuPV/DW2i9wwqW
gyh30PJjyPFl3O9NgPzPyF7Eukk7aiKxgPf8/t+dDwkdqPqhmvE4YwafH1N/
/tmwBWlN9C0dyGbirTGaB4oTapFR9QDvNmMEt4gjWTOagpFvQcmaCLUDP9tb
yfa2wXGGu1Jue9h7nOgh32Af9xVvau2L17WsQlKiCvnN+v34kf11ZeaPOpDR
g/KnpftGcVIQ7R/XvSOomU8ug1oxgds4FrZXHRxBHfWhgl86J/Cys+izgPkI
wh0yH2YuTuDOcl4V72JG0PzoHt1g7Um8vrk2mbI0gqraz4jqFE/it6VcjZ+3
fUczpFBCbdEUTqkrKx69PYrWX42ptFbO4NwC5jedZ5nIz5HnTIUAG7dWtQE9
Xhaao6n8hsuy8cITrhw+ZRYiM7L7urTY+IWQ4PDyKyw0j4U30i+x8TRmTgjl
Ewv9+aY1OegJG99Xx/bLzxxHTNV8/We6C7hx0H3nydOT6OT9cinwXMRvj3Sf
vPFsBt3x/MrdQ1zBh96b/hZcO4NMQ1knj4qv4EfuQ1pE1wxql7ky85a+gs8b
F07Ec8+iua2otmbLFdy+KDzp2a+zKEXGu+Zd/r9/kPJAp+4cmnf6onzPbBVf
33X4vZTzPBLm7Tv16c0a/jYzxjxigY0Kb0kcGM3ZxFuoMSwhwgIqKXvpPlCz
iTPvRkfk7l5AOqEfBKe7N3HpsKjXH9UWUCTqOXR59xZ+x/YWD7/DArru8TjV
OnQLd5SJgEctC2j9jOaUiu02Lvw0UKv0+SJ6con1fUqbg2vsCWw6UbaIxPUX
4/TNOfippAD7TnwR9WbznMu5xsHDIv0TVvsX0buQ142fizj4uIPf+DGRJaQ4
ppALVAKA/G85f4UvoUNiDDerVAJcz3MVHmMso/q3MTLJmURIDEnPSnRZRnXX
CrWSiohQbN6mdth3GT2h2kdn1xBhdkf/eGLcMgpMopmODxDB5yr/DYPaZUTR
9agwkCGBt1hZR4LCCspzuivcl0cC9xhO2qHpFaR8psOnrpoMMXYHlUbWVpDV
2NnA7lYy5B/0KonftYq6dzw6t4fI8PNHe9Ow7CpqDcjkiiJTwBXlr8VdXEUh
XlWX/c5TwHntnM1QxSoS0pdnTIxRwN47Qyb25hqaDSzkUlfigs0+3jb2vTXE
kP/4+Ko+Fzw+ExJhm7GGsgtGM56ZcsE3Neth7fI19OGFaXBAABcYsWi5/4yt
oZesSA+ZJi5Qd01R1jm9jl5lhyYV+XLDkt0djUHBDWTgVfH7py4eSP6yOmAi
tYHmWT+NZ6d5YP8xj4Qy1Q304irBU5vCC+7Sp2ZisQ0Uq3nZlluXF/r6ySU6
NzZQce8s32oKL/x5OVLnTtcG+uZlLiB0iQ/iLgYd1s3aRCvD+bXRbH5IbaX7
vC7YRBo17kl5ggKQZTL8RKVyEwk4NQsyNQTg7bHTFIn2TRSwx+zMD3cB6FWX
/HuLewsZvjawqhoSADXSn66N/ltImh3VoNi9GxrLdiVfMd1Gmw5aVU5MIfi6
v7q+3XobeWQp3QmnCEP/q2vLpu7b6OWOlNEoTRhmn/TYGN7cRqkRk40bBsIg
frdARalyGw0Lz0k4/iEMbi7na6YVd5BGepu8vpgIUMQeMiM3dhBDOcGs+6Io
iM5GCIpyc9DQKPOblZsoKDR76j2nclC21eWz88GiYBh2NKZZk4McvisqROaI
QsjYqIqIAweNPlgrJLNFYfadjlteAweFsaJWxx5RYZo+7ud8ioAtfjATluGI
wdKeweiicwSsJ7RUslmcBpuU9vQlCwIWq7fOSv+FBnzDNXUxDgTMfDjxbLk9
DVTvJ4kUBROwME9FdhPQwHlTr3SxkIDdZNbLdySIQ09L9HyUEBHLitrzOtlE
Ah4YZhtfEidi4YVlc04eEmBR+i5DRYaINecU02/ESkBb2qhRI52IafsZBVs0
S0Cj0/F07lNETKbasFz1/F6oWN06Hh9GxNAue7k+F0kI8BZ7ZHObiBnuNc5d
i5UEnUGNaXo8EetsOcFwfS0JxfU2aS2PiNiXsUUV5RVJyL9XNSlQTsSsIhl9
jvekIE0p4H7SBBFjaib+rGqRBqu0u+MO80SssOpHlPiyNIjyPjumtUrEGAoj
id9kZSBx9hvrK4WE+c98H3b1l4GY9weOisqTsJJ4mxfKCrIQZDY19oBBwlZK
svIMk+XgUqizXkYDCYtawdtIrgqQli3GtfqZhEUYxnfKRyhAN97YZfmVhLlq
Oc9FPFYABkUjcPcgCTty7KM054sCWN9bLP9jhYQFeJ70oh9VBJunUdoe6mRs
uOYXEfF9SpBRp0f8eICMeQeKOJUYKcHA6PhXeT0ydjhViZjhogS2aud9+0+Q
MTWuaTPPPCWwK6WVnLclY9K0N7cFlZXBsSFf82ASGWOFyBp8MlCBnJ/WW8kP
yVhcwUKGtJ0KfOfmb53JJGMNUjFmgzdVwPnc9V9fviJj2zt6k7mtKuDSpV8o
WU/GCulZUz4e+8Cd1axKXCZjb2UyvPvKVSGfN3TVbpOMbfFx1CqHVYGlsb+p
mkjBgmzfvZUXUANP3xT3AEEKliIbWJzrrgZe61desFQpWAhhUb9AUR18+KcU
22womMXa466w93SYCqmm8DtRsLj+wnbvWTp4j8cxTTwoWMydBC9hZQ3w+KRW
WOdPwWQj/GNSUjSgduvFG5PbFEy32gVLl9OE/wHXFt3L
     "]], LineBox[CompressedData["
1:eJwVjns01IkCx6dJD+ZhZn7bjBkm4zV5R2wtKd/cyHtd6zU7HktGEookbenc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     "]], 
    LineBox[{{2.9970122402713466`, -14.061716091321705`}, {2.9970129061176, 
     17.919974320185553`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-5, 5}, {-14.061716091321705`, 17.919974320185553`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.535132071123357*^9, 3.535139656828204*^9, {3.535139771736795*^9, 
   3.5351398014251537`*^9}}]
}, Closed]],

Cell[TextData[{
 "To check thoroughly if this function is one-to-one using the horizontal \
line test, we would have to draw every possible horizontal line on the \
xy-plane and check for each one if it cuts the graph at most once. Since this \
would take more than a lifetime and a complete graph of the function,  it is \
not possible. Even if it were possible, it would be a very boring way to \
spend a lifetime. So in Precalculus, we had  to  satisfy ourselves with the \
assumption that the graph continues to behave as indicated in this 10 X 14 \
snapshot we are using. \n\nBelow we show the graph along with the graphs of  \
some horizontal lines, y = 2, y = -4, y = -2.  We see that they cut the graph \
at most once in each instance.  \n\nThe horizontal line  y = 2 does not cut \
the graph at all.  We can deduce this from the formula for f(x) and some \
algebra. Since the requirement for one-to-oneness is that all horizontal \
lines cut the graph at most once, this does not violate our definition. It \
certainly appears from this portion of the graph that the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "x"}], "+", "1"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", "3"}], ")"}], " "}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is one-to-one. However we have not proved it beyond a shadow of a doubt. \
To do this we need to use information about the graph from the derivative of \
the function. "
}], "Text",
 CellChangeTimes->{{3.535132102551888*^9, 3.535132108332485*^9}, {
   3.535132149283826*^9, 3.535132442655327*^9}, {3.535132475302064*^9, 
   3.5351326371145697`*^9}, {3.535132677208263*^9, 3.535132726044889*^9}, {
   3.535132794707184*^9, 3.535133129858713*^9}, {3.5351332108624897`*^9, 
   3.5351332275319653`*^9}, {3.535137968595159*^9, 3.5351380155698566`*^9}, {
   3.535138047061286*^9, 3.535138429720167*^9}, {3.535139675179233*^9, 
   3.53513968152885*^9}, 3.5351398149044447`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "x", "]"}], ",", " ", "2", ",", " ", 
     RowBox[{"-", "4"}], ",", " ", 
     RowBox[{"-", "1"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", 
     RowBox[{"-", "5"}], ",", " ", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.535133161453032*^9, 3.535133179258173*^9}, {
  3.535133214864071*^9, 3.5351332152235317`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdink41HsfQGfLnm2MZF/D0M1SqLd8fxVtKkKTZN+5blG4vLZbWSLZKmUr
VApF6EHU/X1Q6JJb9uVaajSDbGMb+7zLeZ7znH+OitsVa08SgUB48F//10j2
mXkejwpmNNIaj8dBrHDppcENKgT/VSaTt8VBZ8VHuNWrVCDom86jTQ5S3h+w
eWWBCgKJJd1RaxzUkJguMMqiwnvO7Uurixwk8EuvInymQtkxz3PfJjjoXpCL
xR/ZVKj2HrCJ6OSgEuK1pwRjKvgP2QkPPOOgbZ7HDXY6SsINx9icAVMOovZ9
9C9IkwCTxmGSbf8csm7Mctf+SxzUbvyjax8wh8JnD/mnMsWA38lrtXp2FtX8
nuVXZikKUgnWSieIs+hs+nnlrUwRqGbtqK+bmUbHc9+fPTElBHdwm8nDf0+h
wuawnmuXBKGjVGk+rPwncoq5R/v7BT8Qv99lOnpNoigXcqkwlQ/ExiT7/iU3
gQi7lfCjsRQIvJF3uRZno4HbmfEl3STQ0Z6/SKezkLyQT9HiESLMjj6e608b
Q7/uo28blOfha76ryekV35G78fCLxsZ1vMtiU1+6YhTRQw/wLj9dwVtpfSMq
NkMof8jmQ9jhJTzwVZDyj+g+xL5OO3hcZh7v/f3fW++TOlHtfS3zccY0Pjem
/fSTaSvSm+hf3JPLwtvidPeUJr1DZrWDgpuMUdw6gWTHaA5FAUVlKxLUTvxU
XzXHzx7HGV5q+R0Rb3Git3KjU8IXvLmtP9HQpgbJSaoUthgP4Ad211dYPehE
ZvcqH5fvYuKkENo/HjtHUYuQUha1agK3dynuqNk7ijobwkU/d03gFafQJxGr
UYQ7Z9/PXpjA3ZR8q97EjaI55g7DUP1JvKHlXSplcRTVdJyUNCidxG/KeZg/
bf+GpknhhHclP3FKfUUp8yYTrb4Y02irnsb5Rayuu82wUKCLwMkqEQ5up2kP
RoJsNEvT+A1X5ODFRzx4QupsRGbk9nfrcfCzYaGRlRfZaA6LbKKf5+AZrLww
ykc2+vNVW2rIIw6+q54TWJg9jliahcZPDOdx85C7bpMnJtHRu5Vy4LOA3xzt
OXr1yTS65fOFv5e4jA+/tfgt9N00sghnHz0ovYwfuAsZUd3TqEPh4vRr+jI+
Z148kcg/g2Y3YtpbbJZxp5LIlCe/zqA0Bb+6N4X//UPUB7sMZ9Gc62f1O5Zc
fHXb/rdybnNIXLD/2MdXK/jr7DirqHkOKr4hs4eZt463UuPYYoR5VFbx3Guw
bh1n3Y6Nyt8+jwzC34tO9azj8hExLz9ozaNo1LvvwvYN/JbDDQFh53l0xfth
ul34Bu6iEAUPWufR6kndnxoOm7j442C98qcL6NF59ref+jxcZ0dw85GKBSRt
vJBgbMXDj6UEOXXhC6gvV+B03mUeHhF9LYk7sIDehL1s+lTCw8edA8cPSSwi
1TGVfKASAJR/y/srchHtk2J42qYT4EqBh/gYYwk1vI5TSM0mQnJYZk6y+xKq
v1ysl1JChFKrdq39AUvoEdUpNreOCDNbxoeTE5ZQcArNYnyQCP6XhK+avFtC
FEPvKhMFEvhJVXQmqSyjAtfb4v0FJPCK42Xsm1pG6ic7/etryRDnuFdtdGUZ
2Y6dCu5pI0PhXt+yxG1c1LPl3bU5TIYf3zuaRxS5qC0omy+GTAEPVLiScI6L
wnxrLgSeoYDbymn74SouEjNWZkyMUcDJL0sh/voKmgku5tNW44P1fsF2zp0V
xFD+8PCSMR88PBkW5ZC1gnKLmFlPLPjgq5bdiH7lCnr/zCI0KIgPzNi0/H/G
VtBzdrS3QjMfaHukqRucWEUvcsNTSgL4YdHxls6Q6Boy8a36/WO3AKR+5g4e
l1tDc+wf5jNTArD7kHdSheYaenaJ4KNPEQQv+WPT8dgaite94MBvKAj9A+Qy
g6trqLRvRoibJgh/Xog2uNW9hr76WomInReChHMh+w1z1tHySOG7WI4wpLfR
/V8WrSOdOq+UAlERyDk+8kijeh2JuLaIsnRE4PWhExSZjnUUtMPy5HcvEejT
lv17g38Dmb40sa0ZFgEt0p8eTdc2kDwnplG1Zzs0VWxLvWixidad9WpcWWLw
ZXdtQ4fdJvLOUbsVSRGHgReXlyy8NtHzLTkzJk0cZh712pte30TpUZNNaybi
IH27SEOtehONiM/KuPwhDp7uZ+qmVLeQTma7srGUBFCk7rOi17YQQz3Jsuec
JEjORIlK8vPQMJP11dZTElRafIyeUnko1/bCqblQSTCNOBjXostDzt9UVaLz
JCFsjKkh4cxDzHsrxWSOJMy8MfAsaOShCHYMd+wBFabo44FuxwjYwntLcQWe
FCzuGIotOU3AesPLZVukabBO6chctCZg8Uar7MxfaCA0Ulcf50zArEaST1U6
0UDzbopESSgBi/BR5TQDDdzWjcoXignYdVaDcmeSNPS2xs7FiBGxnJgdL1OP
y8A901zz89JELLK4YtbVWwasy99kaSgQsZa8UvrVeBloz2CaNdGJmH6gWah1
iww0uR7O5D9GxBRqTSs1z+yEKu7G4cQIIoa2OSn1u8tCkJ/UA/ubRMx0p3n+
SrwsGAzpTNETiVhX6xGGx0tZKG2wz2h9QMQ+jy1oqC/LQuGdmkmRSiJmG83o
d7kjBxlqQXdTJogYSzf5R02rPNhm3B53niNixTXfY6SX5EFS8MkhPS4RY6iM
Jn9VVIDkma/sLxQSdm3624jHNQWIe7vnoKQyCStLtH+mrqIIIZY/x+4xSNhy
WU6BaaoSnA93M8pqJGExy3g7yUMFMnKl+LifSFiUaWKXcpQK9OBN3TZfSJiH
ntts1EMVYFB0grcPkbADhz7I8z6rgN2dhco/lklYkM9RX/pBVbB/HKPvrU3G
Rup+kZDepQZZ9UbED3vImF+whGuZmRoMMse/KBuRsf3pasQsdzVw0DoTMHCE
jGnxTVn6FKiBYzmt7IwDGZOnvbopqq4OLo2FuntTyBg7TNHko4kG5P2w20i9
T8YSiuaz5B014Bu/cNt0NhlrlIuzHLquAW6nr/z6/AUZ29wymsxv0wD3buNi
2QYyVkzP+envvQu82C2axCUy9lohy6+/UhMKBcO5jutkbEOIp1U9oglsnd3N
tUQKFuLw5rWyiBb4BKR5BYlSsDTF4NJ8Ly3wXb34jK1JwcIIC8ZFqtpwc1JK
OPMoBSP8Hzr8B6RLvGs=
     "]], LineBox[CompressedData["
1:eJwdjmlQUwcUhSOiNSzJy3vlhYREEpZURRYL1eLG0RoICJSiLGkQhRJEtCgW
I7bSqcqm0CoqBgZEBgGnBSnKUrZSBQQtDloQnIqIgIStVBCYRNTStHfmzv1x
zv3mE4cf9FcaMBgMP/3+d7vvL9aNf8wC4/+RoDximzjOjYW22ide9KQtPIj9
XQWfs9Aq7dsRmW8L1d6adYwMFhpSTlodZdkihNz6ol2t73Pdjwy+tcHWX9vP
qfNYiMrqfR47YQMW1T/mUMqCsU+g55u7NihuXJK7q40FI8Wm8tIkG3Sb7WDU
v2OhL2xX2ZolNqi79bQ02ZCNAt/vpWVz1sjfHyn3N2aDq13XLtNY48DtYzfH
zNmgct/36mmzhuGX+RHmLmysTE6a80y3hkvL5N0j0WyYupZN+PKtcf5waobT
YzZuvjzU8Exmhfn7pTWpfWwcXzHBlG+yQvgHf/Q/H2Jj4N2i/uE1VnB+ynPI
mGKj2zQ4Zq2FFcYLAoZ1hgSUsosRZX+LkW4yckK+nECqa83x7iwxOvqZ9fzP
CJj2aKq1OhEMTHM73HcSCH1S7Kd6KcLa9Q6Dh4MI1Br7dRhoRMi76M9s30Wg
8rT07bYuEQ565gR9E03AI5iniS4TgahYPdt7ikCzkb3QZq8I/smf2l+uJhA5
m/nJqmZLFMunPGtrCRxKCNMlV1ji9eqMyO4GAr6qWy66q5bI7+q8YtpM4KUy
8Co3yRKTokDy2wcE/vE5vMxdZonU+hBt6KjeByWNbp3L0Ti177aIz0H4Eau1
5TNCkC1GzzYKOZiPdF4WpBFCqS6ZDxZxUD/mYsL6UwiTzZPOGRIOrntWuJQ2
CiFPO1S8yJmDPLecgaIzQszaHk0b3M5BZ8zTYJWtEKsUiQGFCRyM97qa9SgF
kMdWk4YnOBh22mwaIBcgNWX0wReJHMQV7fUb8hZguMLbyzqNgxjRUZm9iwD5
JmZuBVkcfPtuNyNusQBmjUUr8iv0+ZnB6KpCCzDEbW9yxjgwTo+NUkzz4bju
dc2bvzhwtCuXndfwEepjp1JM6f2yP4ru7uWj/tjZKb6Wg+mQEeF3rXyoOoOG
sw1JBLn3Gitz+Zg4NdqhtiTRhOgqhRcfPRpmwYUAElEV9xO+LuOhdefp3Npg
EpWv65hVRTxUNy1T9ytIKMdWSHW5PFzKey/dLpxE9XKBOiuNh4DAJarmGBKB
bsZSt308PLrD8JpJIXHDPX4pX8JDZ6F22r+ORGFmRHNFkTk6woe3kJYUTrqr
qpzquBgwvKbLtKJQuDQ+LfYmF7PFUT/zJBRe9EUu1P7EBW9iQiC2p6AIkV0M
y+Ei4qtXWscNFB7VJG4ySuBi/tTCdZ8gCtsFcQ41W7iQFPH4p89SKNujKHR7
SMPVo/ehyQUKGsl5kz33aHiP5aacu0TBQlzbmdxEI9ZeNKe+rOftzAwYqaTR
UCV5WFxC4fHA5q0z2TT8W52TW9ooNHFz/ByVNJRRcxtl7RRir927dCOURrzR
LzPtHRRKfnhV6RpM47Lv+rCubv2/+De5YjuN0R5sHByioLORHBhaQ2M+3mBG
OUJhMrso64IdDVOLlh/Hxil4J1/Z7WlL48PdHtzpaQpy921X7pjTkC5idsTN
6fnlTsx0kkbw1d8TdTq9bxJ/KsiERrQ0fcPxtxTODjd5r1xKI2HE59XCAgVW
iZbLYND4F0mUGXY=
     "]], 
    LineBox[{{2.997012262375859, -13.}, {2.997012762046448, 11.}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8IHGCDAYUpJgnfDbAR/NWPxEgZzBJ81
1d1IMlYIzhe+cTRn0URBOD/o8KxkzVMCcH71e9ucCY/54fwd5bOy1vvzwfl+
k0IV/s3kgfPd5+7183jDBecvO155rTiaE86Pa5kien4FO5xfl8C8jluYDc5n
0JXf79zKAuff6p7ZvvoqE5wvw5Wx8osTI5yfbarFelvm/34YP9n83orDh3/D
+VoVVv/zlvyA8xfeDT5S6fgVzn/eKGrjLvEJzt81VcP1RdhbON/g5c0v+nOf
wfkuu25z/g17AOcXrFz/Q1D4Mpwflqa88FLNTjj/+JmbXcbBO+xhfCvdg5sC
pl+G85nKRO+kSD6A89l5AhqT3j2D85sfXHMuWvwWzt8wuy2g7tNHOD9/UYrA
k7CvcH5c1izZ9sYfcH5nYJml8ZzfcD6LyNRn9b/+wfnXT7d+aOFndIDxQ6uT
zGYdZoLzc7hfK52LYoHz5Vcfm8b2ihXOr97hHMw/mx3OL1iWs81MnxPO52Ey
T9J7ygXnu+aGTNWazAPnS+yUzXdV4YPzJxV1TDS4zg/nB7X5687dJgDna0W3
hC6pFYTzrz3jXDQ5VAjOP5f01FFIXhjOV1sqKdXZj+BD8wucDwBIFNAy
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8IHGMBA4MCUkgTvhtkI/mrG4iUM5gg+
a6q7kWSsEJwvfONozqKJgnB+0OFZyZqnBOD86ve2ORMe88P5O8pnZa3354Pz
/SaFKvybyQPnu8/d6+fxhgvOX3a88lpxNCecH9cyRfT8CnY4vy6BeR23MBuc
z6Arv9+5lQXOv9U9s331VSY4X4YrY+UXJ0Y4P9tUi/W2zP/9MH6y+b0Vhw//
hvO1Kqz+5y35AecvvBt8pNLxK5z/vFHUxl3iE5y/a6qG64uwt3C+wcubX/Tn
PoPzXXbd5vwb9gDOL1i5/oeg8GU4PyxNeeGlmp1w/vEzN7uMg3fYw/hWugc3
BUy/DOczlYneSZF8AOez8wQ0Jr17Buc3P7jmXLT4LZy/YXZbQN2nj3B+/qIU
gSdhX+H8uKxZsu2NP+D8zsAyS+M5v+F8FpGpz+p//YPzr59u/dDCz+gA44dW
J5nNOswE5+dwv1Y6F8UC58uvPjaN7RUrnF+9wzmYfzY7nF+wLGebmT4nnM/D
ZJ6k95QLznfNDZmqNZkHzpfYKZvvqsIH508q6phocJ0fzg9q89edu00AzteK
bgldUisI5197xrlocqgQnH8u6amjkLwwnK+2VFKqsx/Bh+YXOB8ACVXtcg==

     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8IHGMDgw/4pJQneDbMR/NWMxUsYzBF8
1lR3I8lYIThf+MbRnEUTBeH8oMOzkjVPCcD51e9tcyY85ofzd5TPylrvzwfn
+00KVfg3kwfOd5+718/jDRecv+x45bXiaE44P65liuj5Fexwfl0C8zpuYTY4
n0FXfr9zKwucf6t7Zvvqq0xwvgxXxsovToxwfrapFuttmf/7Yfxk83srDh/+
DedrVVj9z1vyA85feDf4SKXjVzj/eaOojbvEJzh/11QN1xdhb+F8g5c3v+jP
fQbnu+y6zfk37AGcX7By/Q9B4ctwflia8sJLNTvh/ONnbnYZB++wh/GtdA9u
Cph+Gc5nKhO9kyL5AM5n5wloTHr3DM5vfnDNuWjxWzh/w+y2gLpPH+H8/EUp
Ak/CvsL5cVmzZNsbf8D5nYFllsZzfsP5LCJTn9X/+gfnXz/d+qGFn9EBxg+t
TjKbdZgJzs/hfq10LooFzpdffWwa2ytWOL96h3Mw/2x2OL9gWc42M31OOJ+H
yTxJ7ykXnO+aGzJVazIPnC+xUzbfVYUPzp9U1DHR4Do/nB/U5q87d5sAnK8V
3RK6pFYQzr/2jHPR5FAhOP9c0lNHIXlhOF9tqaRUZz+CD80vcD4AmXkazQ==

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-5, 5}, {-13., 11.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.535133188823217*^9, 3.5351332185849524`*^9}, 
   3.535139695962639*^9, 3.53513982511168*^9, 3.535149292504573*^9}]
}, Closed]],

Cell["", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Using Derivatives to check if a function is \
one-to-one. ",
 FontColor->RGBColor[
  0.7843137254901961, 0.4470588235294118, 
   0.07058823529411765]]], "Subsubsection",
 CellChangeTimes->{{3.535138648254375*^9, 3.5351386568431673`*^9}, {
  3.535138737513702*^9, 3.535138767910726*^9}, {3.53514491114892*^9, 
  3.5351449417763433`*^9}}],

Cell[TextData[{
 "Using the Mean Value Theorem from Calculus 1, we know that a differentiable \
function (which is continuous on an interval), ",
 StyleBox[" ",
  FontWeight->"Bold"],
 "for which the derivative is always positive or always negative, cannot pass \
through the same y-value twice. Therefore, we can conclude that:\n\n",
 StyleBox["If f(x) is a function which is differentiable, for which the \
derivative is always positive or always negative, then the function f must be \
one-to-one. \n\nExample: ",
  FontWeight->"Bold"],
 "\n We know that f(x)  =(2 x + 1)/(x - 3) is differentiable on its \
domainfrom the laws of derivatives\n studied in Calculus 1. Below, we \
calculate the derivative (which is easily calculated by hand using the \
quotient\n rule). We see that the derivative is always negative since ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", "x", ")"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "7"}], "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", " ", "-", " ", "3"}], ")"}], "^", "2"}]}]}]}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  Therefore, we can conclude that the function is one-to-one on the \
interval (-\[Infinity], 3) and also on the interval (3, \[Infinity]). Now we \
can use elementary algebra to show that \n f(x) < 2 if x < 3, and f(x) > 2 if \
x > 3. Therefore the function cannot pass through the same y-value twice and \
we have shown (this time beyond a shadow of doubt) that f is a one-to-one \
function. Instead of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "x", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", we will  use the symbol Df(x) to refer to   the derivative of f, since \
the prime symbol is protected in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". \n "
}], "Text",
 CellChangeTimes->{{3.535138673844646*^9, 3.535138677913744*^9}, {
  3.535138783300857*^9, 3.535138951935747*^9}, {3.535138998127112*^9, 
  3.5351392419730673`*^9}, {3.535139287236195*^9, 3.535139613048904*^9}, {
  3.535139835420433*^9, 3.535140223091753*^9}, {3.535140265810225*^9, 
  3.5351404217123404`*^9}, {3.535140461152802*^9, 3.535140666544249*^9}, {
  3.535140727559175*^9, 3.535140851068437*^9}, {3.535140910640462*^9, 
  3.53514113982612*^9}},
 TextAlignment->Left,
 LineSpacing->{1, 3}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], ",", "x"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.5351407074096813`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["7", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", "x"}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{3.535140717185972*^9, 3.535149308597694*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Df", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "7"}], "/", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", "-", "3"}], ")"}], "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.535140863486175*^9, 3.535140901235023*^9}}],

Cell["", "Text"],

Cell["", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise: ", "Subsubsection",
 CellChangeTimes->{{3.535146248116996*^9, 3.535146253138173*^9}, 
   3.535146760788163*^9}],

Cell[TextData[{
 "Use the commands shown above to sketch the graph of the function m(x) = ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SqrtBox["x"], "/", 
    RowBox[{"(", 
     RowBox[{"3", "-", 
      SuperscriptBox["x", "2"]}], ")"}]}], ","}]],
  CellChangeTimes->{{3.535146944145083*^9, 3.535146974013728*^9}}],
 " find its derivative and check whether it is one-to-one on its domain. "
}], "Text",
 CellChangeTimes->{{3.535146821932354*^9, 3.53514687764153*^9}, {
   3.535147054542636*^9, 3.5351471319764137`*^9}, {3.535158532218471*^9, 
   3.535158538108252*^9}, 3.535158880057726*^9, 3.535158970987059*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Restricting The Domain of A Function.",
 FontColor->GrayLevel[0]]], "Subsection",
 CellGroupingRules->{"SectionGrouping", Inherited},
 CellChangeTimes->{{3.53512992993111*^9, 3.535129935537665*^9}, {
  3.535130811761403*^9, 3.535130831319848*^9}, {3.535130960327834*^9, 
  3.535130979654214*^9}, {3.53513145944899*^9, 3.5351315188111973`*^9}, {
  3.5351377981122847`*^9, 3.535137818504463*^9}, {3.5351413007451468`*^9, 
  3.535141313029675*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Modified definition: a function which is one-to-one \
on an interval (a, b).",
 FontColor->RGBColor[
  0.8099488822766461, 0.4050507362478065, 0.]]], "Subsubsection",
 CellChangeTimes->{{3.535138648254375*^9, 3.5351386568431673`*^9}, {
   3.535138737513702*^9, 3.535138767910726*^9}, 3.535141367823964*^9, {
   3.535142028281364*^9, 3.5351420554844427`*^9}, {3.5351423939921494`*^9, 
   3.535142509262906*^9}, {3.535142812118362*^9, 3.535142815339088*^9}}],

Cell[TextData[{
 "We say that a function f(x) is one to one on the interval (a, b), if ",
 StyleBox["y-value  appears at most  once on the graph of the function",
  FontWeight->"Plain"],
 " on that interval. \n",
 StyleBox["This translates to an ",
  FontWeight->"Plain"],
 StyleBox["algebraic statement",
  FontWeight->"Bold"],
 StyleBox[" of the following form: f is a one-to-one function on the interval \
(a, b) if \nwhenever f(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], ")"}], " ", "=", " ", "f"}], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["x", "2"], ")"}], TraditionalForm]],
  FontWeight->"Plain"],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], "and", "  ", 
    SubscriptBox["x", "2"], " ", "are", " ", "in", " ", "the", " ", 
    "interval", " ", 
    RowBox[{"(", 
     RowBox[{"a", ",", " ", "b"}], ")"}]}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", then ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], "=", " ", 
    RowBox[{
     SubscriptBox["x", "2"], "."}]}], TraditionalForm]],
  FontWeight->"Plain"],
 " \nThis also translates to the statement:",
 StyleBox[" the function ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   OverscriptBox["f", "^"], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontWeight->"Bold"],
 StyleBox[" is one-to-one",
  FontWeight->"Bold"],
 " where ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["f", "^"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is the piecewise defined function defined below:\n ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["f", "^"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Piecewise]", GridBox[{
      {
       RowBox[{
        RowBox[{"f", "(", "x", ")"}], ",", " "}], 
       RowBox[{"x", " ", "\[Epsilon]", " ", 
        RowBox[{"(", 
         RowBox[{"a", ",", " ", "b"}], ")"}]}]},
      {
       RowBox[{"undefined", ",", " "}], 
       RowBox[{"x", " ", "not", " ", "in", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", ",", " ", "b"}], ")"}], "."}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.84]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\n",
 StyleBox["It also translates to a ",
  FontWeight->"Plain"],
 StyleBox["geometric statement",
  FontWeight->"Bold"],
 StyleBox[" of the form:\nA function ",
  FontWeight->"Plain"],
 StyleBox["f is one-to-one on the interval (a, b),  if every horizontal line \
cuts the graph of the function ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   OverscriptBox["f", "^"], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontWeight->"Bold"],
 StyleBox[" defined above at most once. \n\n",
  FontWeight->"Bold"],
 StyleBox["Thus we ",
  FontWeight->"Plain"],
 StyleBox["can check if  f is one-to-one on the interval (a, b) by using  the \
horizontal line test on the restricted function ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   OverscriptBox["f", "^"], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontWeight->"Bold"],
 StyleBox[".",
  FontWeight->"Bold"],
 StyleBox["\nWe can also use the Mean value theorem from Calculus 1 to get:\n",
  FontWeight->"Plain"],
 StyleBox["If f(x) is continuous and differentiable on the open interval (a, \
b) and either f\[CloseCurlyQuote](x) is always positive or \
f\[CloseCurlyQuote](x) is always negative, then f(x) is one-to-one on the \
interval (a, b). ",
  FontWeight->"Bold"],
 StyleBox["\n\n",
  FontWeight->"Plain"]
}], "Text",
 CellChangeTimes->{{3.535142533687523*^9, 3.5351425357090054`*^9}, {
   3.535142618211604*^9, 3.5351428010608597`*^9}, 3.535142855532535*^9, {
   3.535142888933819*^9, 3.5351429486338787`*^9}, {3.5351429907826223`*^9, 
   3.535143115873438*^9}, {3.535143148153295*^9, 3.53514328859685*^9}, {
   3.535143324280796*^9, 3.535143475654915*^9}, {3.535144166524494*^9, 
   3.535144297090069*^9}, 3.5351443404107027`*^9},
 TextAlignment->Left]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Restricting the domain of a function to create a \
one-to-one function. ",
 FontColor->RGBColor[
  0.8099488822766461, 0.4050507362478065, 0.]]], "Subsubsection",
 CellChangeTimes->{{3.5351445253812733`*^9, 3.535144529482704*^9}, {
  3.5351446556528473`*^9, 3.5351447401114798`*^9}}],

Cell[TextData[{
 "If a function f(x) is not one-to-one on its entire domain, we can sometimes \
restrict the domain to create a piecewise defined function which is \
one-to-one. \n\nIf a function f(x) is one to one on an interval (a, b), then \
the piecewise defined function  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["f", "^"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "  defined above is a one-to-one function. (Note: that  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["f", "^"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "  is just  the function f(x) restricted to the domain (a, b)). \n\nWe will \
look at the example h(x) = sin(x). First we graph the function h(x) = sin(x) \
and we see that it does not pass the horizontal line test. \n"
}], "Text",
 CellChangeTimes->{{3.535144977273672*^9, 3.535145263590391*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sin", "[", "x", "]"}], ",", "0.5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "Pi"}], ",", 
         RowBox[{
          RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", "0", ",", " ", 
         RowBox[{"Pi", "/", "2"}], ",", " ", "Pi"}], "}"}], ",", 
       "Automatic"}], "}"}]}]}], "]"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{3.535145360522434*^9, 3.535149362604095*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2Xk0VP/7APARihKhUlHRIkpSafmgnhGJKEuSJEWbSki0qpAUqSylkqUQ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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7eXJ5/xbkfMAAxg8sE8/fvvDhsUccH6L68p5aaoI
fuGVX0KThdnh/FOxUi+eCLPB+X/3rdpgJckK5z/e9HFiICcLnG+2kO1KLzcz
nG+jdEmv+wcjnC9TzVfb84oBzr8wxzAi7e7//TD++YzNz013/4Xzl2letAjY
+xvON5h1oaDo5E84X9HA9pbY6u9w/qtdrqxsG7/C+dLZuxPLez7D+f9OCS39
UPgRzi+25wnJ/P4Ozt9hfPbA162v4Pz1gsc2iO99hlBvNZPZLv8RnG/VGu/x
IusOnP8+409/fccVOL/5yGwr+x/H4fxru22OrGLeAOfH67j9DZm4zh7Gf+gR
EZo37wSc/2W9/XoJ6ytw/q2lcnkfL9yB86vzdnuEzn8E50cs0A+f0/sMzk9r
P8l0/8IrOP9wi7Z2z+l3cH6c4NNDIpEf4fzPVsftHpZ9hvPX5/P+TCr4Cuez
1D9rTJryHc5vnKnsKT7lJ5zvzVKveaTzN5y/zjP3xruVf+F8i1n7j55b+h8h
n3TJQewZgwPcvQoh2o5fGOH8TY/Zt7p9YILzvURY1boZWeD8Mi8Ts1UMrHD+
yRWfgo7+QvAzSn6FyXOxw/mzXU1+BbNzwPlF7gvnLZ+C4EPzC5wPAGA2DKk=

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{-Pi, Pi}, {-0.9999998782112116, 
     0.9999998592131705}}, {{-3.141592653589793, 
    3.141592653589793}, {-0.9999998782112116, 0.9999998592131705}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{
      NCache[-Pi, -3.141592653589793], 
      FormBox[
       RowBox[{"-", "\[Pi]"}], TraditionalForm]}, {
      NCache[Rational[-1, 2] Pi, -1.5707963267948966`], 
      FormBox[
       RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {
      NCache[Rational[1, 2] Pi, 1.5707963267948966`], 
      FormBox[
       FractionBox["\[Pi]", "2"], TraditionalForm]}, {
      NCache[Pi, 3.141592653589793], 
      FormBox["\[Pi]", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.53514536716462*^9, 3.535149370035326*^9}]
}, Open  ]],

Cell[TextData[{
 "By inspecting the graph, using the horizontal line test or by calculating \
the derivative, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"h", "'"}], 
     RowBox[{"(", "x", ")"}]}], " ", "=", " ", 
    RowBox[{"cos", 
     RowBox[{"(", "x", ")"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", we see that the function is one-to-one on the interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"-", "\[Pi]"}], "2"], ",", " "}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 Cell[BoxData[
  FormBox[
   FractionBox["\[Pi]", "2"], TraditionalForm]]],
 "). Thus the piecewise defined function \n\n",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    RowBox[{"h", " "}], "^"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Piecewise]", GridBox[{
      {
       RowBox[{
        RowBox[{"sin", "(", "x", ")"}], ",", " "}], 
       RowBox[{"x", " ", "\[Epsilon]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "2"], ",", " ", 
          FractionBox["\[Pi]", "2"]}], ")"}]}]},
      {
       RowBox[{"undefined", ",", " "}], 
       RowBox[{"x", " ", "not", " ", "in", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "2"], ",", " ", 
          FractionBox["\[Pi]", "2"]}], ")"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.84]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\nis one to one. Consequently the graph of this piecewise defined function \
shown below passes the horizontal line test. \nThis function is called the \
restricted sine function and will be used to define the inverse sine function \
(arcsin) in Calculus 2.\n"
}], "Text",
 CellChangeTimes->{{3.535145486911098*^9, 3.5351457141016073`*^9}, {
  3.535145761833014*^9, 3.53514586591291*^9}, {3.535145907752092*^9, 
  3.535145957989648*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], ",", "0.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "Pi"}], "/", "4"}], ",", "0", ",", 
        RowBox[{"Pi", "/", "4"}], ",", "  ", 
        RowBox[{"Pi", "/", "2"}]}], "}"}], ",", "Automatic"}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.535146019935615*^9, 3.5351460293003607`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt13k0Fu0bB3BLSVHZSqkopETSSxtyEWXp1aJNKksrbUqiooVCyZJQlBBl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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7eXJ5/xb8ed+BjB4YJ9+/PaHDYt/wPktrivnpaki
+IVXfglNFv4O55+KlXrxRPgbnP9336oNVpJf4fzHmz5ODOT8AuebLWS70sv9
Gc63Ubqk1/3jI5wvU81X2/PqA5x/YY5hRNrd93D++YzNz013v4Xzl2letAjY
+xrON5h1oaDo5Es4X9HA9pbY6udw/qtdrqxsG5/C+dLZuxPLex7D+f9OCS39
UPgQzi+25wnJ/H4Pzt9hfPbA16234Pz1gsc2iO+9hlBvNZPZLv8SnG/VGu/x
IusMnP8+409/fccROL/5yGwr+x/b4fxru22OrGJeAOfH67j9DZk4zx7Gf+gR
EZo3bwec/2W9/XoJ6yNw/q2lcnkfL5yB86vzdnuEzr8E50cs0A+f03sNzk9r
P8l0/8ItOP9wi7Z2z+l7cH6c4NNDIpEP4fzPVsftHpY9hvPX5/P+TCp4Cuez
1D9rTJryHM5vnKnsKT7lJZzvzVKveaTzNZy/zjP3xruVb+F8i1n7j55b+h4h
n3TJQezZB4R7FUK0Hb98hPM3PWbf6vbhE5zvJcKq1s34Bc4v8zIxW8XwFc4/
ueJT0NFfCH5Gya8wea7vcP5sV5Nfwew/4Pwi94Xzlk9B8KH5Bc4HAJq3HVU=

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{Rational[-1, 2] Pi, Rational[1, 2] Pi}, {-0.9999999999999979, 
     0.9999999999999979}}, {{-1.5707963267948966`, 
    1.5707963267948966`}, {-0.9999999999999979, 0.9999999999999979}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{
      NCache[Rational[-1, 2] Pi, -1.5707963267948966`], 
      FormBox[
       RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], TraditionalForm]}, {
      NCache[Rational[-1, 4] Pi, -0.7853981633974483], 
      FormBox[
       RowBox[{"-", 
         FractionBox["\[Pi]", "4"]}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {
      NCache[Rational[1, 4] Pi, 0.7853981633974483], 
      FormBox[
       FractionBox["\[Pi]", "4"], TraditionalForm]}, {
      NCache[Rational[1, 2] Pi, 1.5707963267948966`], 
      FormBox[
       FractionBox["\[Pi]", "2"], TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.535146033061792*^9, 3.535149379278792*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Exercise
\
\>", "Subsubsection",
 CellChangeTimes->{{3.535147188319325*^9, 3.5351471945408373`*^9}}],

Cell[TextData[{
 "Use the graphs of  the following functions to determine an interval upon \
which the functions are one-to-one. \nDefine restricted functions which are \
one-to-one and plot their graphs. \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", " ", 
     RowBox[{"(", "x", ")"}]}], " ", "=", " ", 
    FractionBox[
     SuperscriptBox["x", "2"], 
     RowBox[{
      RowBox[{"5", 
       SuperscriptBox["x", "2"]}], "-", "3"}]]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ",    p(x) = cos(x). "
}], "Text",
 CellChangeTimes->{{3.535147203974166*^9, 3.535147367384121*^9}, 
   3.535147422440209*^9, {3.535147721709041*^9, 3.535147811252137*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inverse Functions", "Section",
 CellChangeTimes->{{3.5351489220139723`*^9, 3.535149039612145*^9}, {
  3.5351490984199047`*^9, 3.5351491042874537`*^9}, {3.535155634886423*^9, 
  3.535155643570376*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Definition of an Inverse Function.",
 FontColor->GrayLevel[0]]], "Subsection",
 CellChangeTimes->{{3.535149053205377*^9, 3.535149083561678*^9}, {
  3.5351491739575787`*^9, 3.535149192649705*^9}}],

Cell[TextData[{
 "If f(x) is a one-to-one function with domain A and range B, we can define \
an inverse function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], "(", "x", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (with domain B) by the rule "
}], "Text",
 CellChangeTimes->{{3.535149639838749*^9, 3.535149746983309*^9}, 
   3.53514982961698*^9}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(y) = x   if and only if   f(x) = y."
}], "Text",
 CellFrame->{{0.5, 3}, {3, 0.5}},
 CellChangeTimes->{{3.535149768623788*^9, 3.535149832248333*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "(Note that the reason we require a one-to-one function f(x) in the \
definition is to ensure that ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(y) satistfies the definition of a function, that is, for any given value \
of y, we want a unique vlaue of x = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(y). )"
}], "Text",
 CellChangeTimes->{{3.5351517122783012`*^9, 3.535151826573222*^9}, {
  3.5351518729381123`*^9, 3.5351519619164677`*^9}}],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
 CellChangeTimes->{{3.535156646498734*^9, 3.535156648960052*^9}}],

Cell["\<\
  In a previous section  we showed that the function given  below is \
one-to-one.\
\>", "Text",
 CellChangeTimes->{{3.535153147274021*^9, 3.535153165436965*^9}, {
   3.535153244458*^9, 3.535153305628418*^9}, 3.5351566695293627`*^9}],

Cell[TextData[{
 "f(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", "x"}], " ", "+", " ", "1"}], 
    RowBox[{"x", " ", "-", " ", "3"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.53515318172661*^9, 3.535153230700158*^9}},
 TextAlignment->Center],

Cell[TextData[{
 "Therefore we can define a new function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], " ", "for", " ", "which", " "}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " the statement ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(y) = x   is equivalent to the statement  f(x) = y.\nSubstituting the \
variable y for  f(x) in the equation above, we have that the equation"
}], "Text",
 CellChangeTimes->{{3.535153325797727*^9, 3.5351534462476797`*^9}, {
   3.535153481282587*^9, 3.535153595739579*^9}, 3.5351537548580027`*^9}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(y) = x  is the same as the equation  ",
 "y = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", "x"}], " ", "+", " ", "1"}], 
    RowBox[{"x", " ", "-", " ", "3"}]], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.53515318172661*^9, 3.535153230700158*^9}, {
   3.535153587675597*^9, 3.5351535894737873`*^9}, 3.535153739995924*^9},
 TextAlignment->Center],

Cell[TextData[{
 "To find and expression for  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(y)  in terms of y, we need to solve for x in terms of y in the equation on \
the right hand side above.  We can solve this with high school algebra. We \
use the command ",
 StyleBox["Solve",
  FontSlant->"Italic"],
 " in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.535153614833433*^9, 3.535153729487995*^9}, {
  3.535153772079062*^9, 3.535153920995657*^9}, {3.535153966970709*^9, 
  3.535153974000854*^9}, {3.535154033006328*^9, 3.5351540682098513`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"2", "x"}], "+", "1"}], 
    RowBox[{"x", "-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"y", "\[Equal]", 
    RowBox[{"f", "[", "x", "]"}]}], ",", " ", "x"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.535153990827733*^9, {3.535154072139737*^9, 3.53515411140235*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    FractionBox[
     RowBox[{"1", "+", 
      RowBox[{"3", " ", "y"}]}], 
     RowBox[{
      RowBox[{"-", "2"}], "+", "y"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5351540096016083`*^9, 3.53515411716371*^9}]
}, Open  ]],

Cell[TextData[{
 "Thus we get a formula for the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], ":"}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.535154236760722*^9, 3.535154270871128*^9}}],

Cell[TextData[{
 "x =  ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "y"}]}], 
    RowBox[{"y", "-", "2"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "   or     ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(y) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "y"}]}], 
    RowBox[{"y", "-", "2"}]], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellFrame->0.5,
 CellFrameColor->GrayLevel[1],
 CellChangeTimes->{{3.535154288693674*^9, 3.5351543403710117`*^9}, {
  3.535156355495215*^9, 3.5351563687156267`*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "When discussing the relationship between the two functions ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 " above, the roles of the variables x and y were important and it was \
important not to mix up  these variables when solving for x in terms of y. \
However one we have \ndetermined a formula for the function ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(y) in terms of the variable y, it does not matter what we call the \
variable. So if we want to discuss the behavior of the  function ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 " we can choose any name for the variable. We can rewrite the description of \
the function ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 " above as \n"
}], "Text",
 CellChangeTimes->{{3.535154475624989*^9, 3.5351546473717546`*^9}, {
  3.535154678633976*^9, 3.535154909846611*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(u) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "u"}]}], 
    RowBox[{"u", "-", "2"}]], TraditionalForm]]],
 "    or    ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "x"}]}], 
    RowBox[{"x", "-", "2"}]], TraditionalForm]]],
 "    or    ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(",
 "\[Section]",
 ") = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "\[Section]"}]}], 
    RowBox[{"\[Section]", "-", "2"}]], TraditionalForm]]]
}], "Text",
 CellFrame->0.5,
 CellFrameColor->GrayLevel[1],
 CellChangeTimes->{{3.535154288693674*^9, 3.5351543403710117`*^9}, {
  3.535154924323893*^9, 3.53515499999977*^9}, {3.535155068713893*^9, 
  3.535155088489019*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "Usually, we like to discuss the behavior of functions in the xy-plane where \
the independent variable is x. So when graphing the function ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 " below, we write  the function with independent variable x as   ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "x"}]}], 
    RowBox[{"x", "-", "2"}]], TraditionalForm]]],
 " and draw the graph of the associated equation  y = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "x"}]}], 
    RowBox[{"x", "-", "2"}]], TraditionalForm]]],
 " or  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(x). \n [ Note that the equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(x) is equaivalent to the equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", " ", "f"}], TraditionalForm]]],
 "(y). We will graph both equations together below and explore the strong \
connection between the graphs. ]\n \n We now have "
}], "Text",
 CellChangeTimes->{{3.535155116879228*^9, 3.5351553618688602`*^9}, {
   3.535155396422328*^9, 3.535155494701548*^9}, {3.535156437977317*^9, 
   3.5351564948107767`*^9}, 3.535156707928589*^9, {3.535190961830412*^9, 
   3.5351910240373907`*^9}}],

Cell[TextData[{
 "f(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", "x"}], " ", "+", " ", "1"}], 
    RowBox[{"x", " ", "-", " ", "3"}]], TraditionalForm]]],
 "   and    ",
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "x"}]}], 
    RowBox[{"x", "-", "2"}]], TraditionalForm]]]
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.53519104112222*^9, 3.535191080974736*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "The definition of the inverse function says that when y = f(x), we should \
have ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(y) and vice versa. We demonstarte this by calculating the  values of f(6), \
f(2) and f(-1). We find that they are equal to 13/3, -5 and 1/4 respectively. \
As  predicted, we find that ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(13/3), ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(-5) and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(1/4) are 6, 2 and -1 respectively.  Below, we use  ",
 StyleBox["finv",
  FontSlant->"Italic"],
 " to denote the inverse function since the symbol ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontColor->GrayLevel[0]],
 " is protected in Mathematica because of its ambiguity."
}], "Text",
 CellChangeTimes->{{3.535191122344596*^9, 3.535191191586429*^9}, {
  3.535191231890964*^9, 3.535191275197153*^9}, {3.535191313877784*^9, 
  3.53519131435823*^9}, {3.53519151440901*^9, 3.5351916711169357`*^9}, {
  3.535231285949603*^9, 3.5352313110513277`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "x"}], "+", "1"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "-", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"finv", "[", "x_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"3", "x"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", " ", "-", " ", "2"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"List", "[", 
  RowBox[{
   RowBox[{"f", "[", "6", "]"}], ",", " ", 
   RowBox[{"f", "[", "2", "]"}], ",", " ", 
   RowBox[{"f", "[", 
    RowBox[{"-", "1"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.535191347557384*^9, 3.535191404014881*^9}, {
  3.5351914526316547`*^9, 3.5351914737148*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["13", "3"], ",", 
   RowBox[{"-", "5"}], ",", 
   FractionBox["1", "4"]}], "}"}]], "Output",
 CellChangeTimes->{{3.535191385048551*^9, 3.535191408346642*^9}, 
   3.535191477753137*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"List", "[", 
  RowBox[{
   RowBox[{"finv", "[", 
    RowBox[{"13", "/", "3"}], "]"}], ",", " ", 
   RowBox[{"finv", "[", 
    RowBox[{"-", "5"}], "]"}], ",", " ", 
   RowBox[{"finv", "[", 
    RowBox[{"1", "/", "4"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5351915020334587`*^9, 3.5351915028316307`*^9}, {
  3.535191733345228*^9, 3.535191760639884*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "2", ",", 
   RowBox[{"-", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5351917656568336`*^9}]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Finding a formula for the inverse function.",
  FontColor->GrayLevel[0]],
 " "
}], "Subsection",
 CellGroupingRules->{"SectionGrouping", Inherited},
 CellChangeTimes->{{3.535155542124298*^9, 3.535155567551475*^9}}],

Cell[TextData[{
 "The general principles in the above calculation are outlined below. \nGiven \
a one-to-one function with associated equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", " ", "=", " ", "f"}], TraditionalForm]]],
 "(x), we find a formula for ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(x) in terms of the variable x using the following method\n1. Solve for ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " in terms of ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " in the equation  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", " ", "=", " ", "f"}], TraditionalForm]]],
 "(x) to get an expression  of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(y).\n2. Switch  ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " and  ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " in the resulting equation to convert the equation to one of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(x). "
}], "Text",
 CellGroupingRules->"NormalGrouping",
 CellChangeTimes->{{3.535155787451962*^9, 3.535155938294705*^9}, 
   3.5351562318069553`*^9, {3.535156286779419*^9, 3.5351563000721903`*^9}}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["Exercise:", "Subsubsection",
 CellChangeTimes->{{3.535156768786646*^9, 3.535156784849262*^9}}],

Cell[TextData[{
 "Show that the function Q(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"2", "x"}], 
    RowBox[{"x", " ", "+", " ", "4"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is a one-to-one function and use the ",
 StyleBox["Solve",
  FontSlant->"Italic"],
 " command to find a formula for the inverse  function ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Q", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(x). \n"
}], "Text",
 CellChangeTimes->{{3.5351576086524754`*^9, 3.5351576149605293`*^9}, {
  3.5351576543983097`*^9, 3.535157727490933*^9}, {3.535158020609982*^9, 
  3.535158061935252*^9}, {3.53515851255175*^9, 3.53515851837632*^9}, {
  3.5351587616019506`*^9, 3.535158868390592*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Composing f and ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.535190086069886*^9, 3.535190122696199*^9}, {
  3.5351908229191513`*^9, 3.535190842009796*^9}}],

Cell[TextData[{
 "From the definition of the function ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ", we have;   when y = f(x), then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(y) and vice versa. Substituting y = f(x) in the formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(y)  gives that:"
}], "Text",
 CellChangeTimes->{{3.53519014708961*^9, 3.535190208866268*^9}, {
  3.535190253298973*^9, 3.535190302848817*^9}, {3.5351903625307493`*^9, 
  3.535190487238583*^9}, {3.535190540309379*^9, 3.535190542348967*^9}, {
  3.535231375279832*^9, 3.5352313787163553`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"x", " ", "=", " ", 
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]], "(", 
     RowBox[{"f", "(", "x", ")"}], ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.535190499886504*^9, 3.535190546244989*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "By switching the roles of x and y in the above statements, we get that x = \
f(y) when y = ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(x), and substituting ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 "(x) into the equation x = f(y), we get   "
}], "Text",
 CellChangeTimes->{{3.535190580859901*^9, 3.535190712178164*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"x", " ", "=", " ", 
    RowBox[{"f", "(", 
     RowBox[{
      SuperscriptBox["f", 
       RowBox[{"-", "1"}]], "(", "x", ")"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ")."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.5351907305969343`*^9, 3.535190752463829*^9}, 
   3.535190785782913*^9},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "Therefore when we compose f and ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ", we get the identity function.  We check this out in our running example.\n"
}], "Text",
 CellChangeTimes->{{3.535190855866119*^9, 3.535190887943276*^9}, {
  3.535226553703587*^9, 3.535226568971834*^9}}],

Cell[CellGroupData[{

Cell["Example: ", "Subsubsection",
 CellChangeTimes->{{3.5351908978957243`*^9, 3.535190901749255*^9}}],

Cell["We have shown above that if ", "Text",
 CellChangeTimes->{{3.535226630745647*^9, 3.5352266406711187`*^9}}],

Cell[TextData[{
 "f(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", "x"}], " ", "+", " ", "1"}], 
    RowBox[{"x", " ", "-", " ", "3"}]], TraditionalForm]]],
 ",    then     ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "x"}]}], 
    RowBox[{"x", "-", "2"}]], TraditionalForm]]],
 "."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.53519104112222*^9, 3.535191080974736*^9}, {
  3.535226646530005*^9, 3.535226664302916*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "x"}], "+", "1"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "-", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"finv", "[", "x_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"3", "x"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", " ", "-", " ", "2"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"f", "[", 
   RowBox[{"finv", "[", "x", "]"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.535226685367865*^9, 3.535226690247388*^9}, {
  3.5352305828874063`*^9, 3.5352305899147253`*^9}}],

Cell[BoxData["x"], "Output",
 CellChangeTimes->{3.5352305953975153`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"finv", "[", 
   RowBox[{"f", "[", "x", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.535230608898057*^9, 3.535230616647318*^9}}],

Cell[BoxData["x"], "Output",
 CellChangeTimes->{3.535230622802697*^9}]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.535230720197151*^9, 3.535230741092971*^9}}],

Cell["", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise:", "Subsubsection",
 CellChangeTimes->{{3.535230789476231*^9, 3.535230793745821*^9}}],

Cell[TextData[{
 "Use the formula you found for the inverse function of  Q(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"2", "x"}], 
    RowBox[{"x", " ", "+", " ", "4"}]], TraditionalForm]]],
 " above show that Q",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(Q(x)) = x  and  Q(Q",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x)) = x. "
}], "Text",
 CellChangeTimes->{{3.5352308011907883`*^9, 3.5352308590466022`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["The graph of y = ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]], "(", "x", ")"}], "."}], TraditionalForm]],
  FontColor->GrayLevel[0]]
}], "Subsection",
 CellChangeTimes->{{3.535157879666774*^9, 3.535157906365944*^9}}],

Cell[TextData[{
 "\nFrom precalculus, we know that  if we switch  the roles of x and y in an \
equation the graph of the new equation \nis the reflection of the graph of \
the old equation in the line ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", " ", "=", " ", "x"}], TraditionalForm]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.535159022431747*^9, 3.535159265089253*^9}, {
   3.535159295290039*^9, 3.535159513829834*^9}, 3.535159826524295*^9, {
   3.535231818986092*^9, 3.5352318202227917`*^9}}],

Cell[TextData[{
 "We saw above that  ",
 StyleBox["y = ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       RowBox[{"-", "1"}]], "(", "x", ")"}], "  ", "if", " ", "and", " ", 
     "only", " ", "if", "   ", "x"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"f", "(", "y", ")"}], " ", "."}]}], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontColor->GrayLevel[0]],
 "\nTherefore both of the above equations describe the graph of  same curve \
in the xy plane, the graph of the \nfunction ",
 Cell[BoxData[
  RowBox[{"y", " ", "=", " ", 
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", "x", ")"}], " "}]}]],
  FontColor->GrayLevel[0]],
 ". \nNow if we switch the roles of x and y in the equation  x = f(y)  we get \
the equation y = f(x). \nThus the graph of the function y = f(x) is the \
reflection of the graph of the function  ",
 StyleBox["y = ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]], "(", "x", ")"}], "  "}], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontColor->GrayLevel[0]],
 " in the line y = x."
}], "Text",
 CellChangeTimes->{{3.5351595469190063`*^9, 3.5351596867986603`*^9}, {
  3.535159719618153*^9, 3.535159812128069*^9}, {3.535160753904646*^9, 
  3.5351607567004004`*^9}}],

Cell[TextData[{
 "Note that if a point (x",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", y",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") is on the graph of y = f(x), then the point (y",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", x",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") is on the graph of ",
 StyleBox["y = ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]], "(", "x", ")"}], " ", "."}], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.535160763636476*^9, 3.5351608845225277`*^9}}],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
 CellChangeTimes->{{3.5351598822307043`*^9, 3.535159883812117*^9}, {
  3.535160192258123*^9, 3.535160201767308*^9}}],

Cell[TextData[{
 "We use the formula we derived for ",
 StyleBox[" ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]], "(", "x", ")"}], "  "}], TraditionalForm]],
  FontColor->GrayLevel[0]],
 " above to demonstarte how the graphs are related. We use ",
 StyleBox["finv",
  FontSlant->"Italic"],
 " to denote the inverse function since the symbol ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontColor->GrayLevel[0]],
 " is protected in Mathematica because of its ambiguity. (I use the ",
 StyleBox["Exclusions",
  FontSlant->"Italic"],
 " option here to eliminate the vertical asymptotes in the graphs at x = 2 \
and x = 3.)"
}], "Text",
 CellChangeTimes->{{3.535160257717607*^9, 3.535160351757518*^9}, {
  3.5351624365668383`*^9, 3.535162481946434*^9}, {3.53516272205086*^9, 
  3.5351627336503763`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "x"}], "+", "1"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "-", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"finv", "[", "x_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"3", "x"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", " ", "-", " ", "2"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "x", "]"}], ",", 
     RowBox[{"finv", "[", "x", "]"}], ",", "x"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"Exclusions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Green", ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", " ", "Dashed"}], "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.535160231968299*^9, 3.5351602482384567`*^9}, {
   3.535160413253562*^9, 3.535160441290229*^9}, {3.535160505415708*^9, 
   3.535160560844261*^9}, {3.535160592450968*^9, 3.535160625784081*^9}, {
   3.535161090834305*^9, 3.535161117112739*^9}, 3.535162414919188*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwVi3k4FGofhgdx7DtHlEgliso4IeoXhVIoe0eJLG1ClghJdhVRWlBJUsiS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      "]], LineBox[CompressedData["
1:eJwB4QEe/iFib1JlAgAAAB0AAAACAAAACApQ+f8HAED8KIUEHBwUwBzuEvT/
HABA9XT7DfVmFMB02KfqUzgAQG77TBO5yhTAJK3R1/tuAEBVgZcSs5oVwHyX
Zs5PigBAeYvO7CYHFsDUgfvEo6UAQLPNyezAdhbAhFYlskvcAEC13qcC+F8X
wNxAuqif9wBA96L95+LZF8A0K0+f8xIBQGzVnuiPVxjA5P94jJtJAUCBqjPX
514ZwESpzGbrtgFAjP7TSUOjG8Cck2FdP9IBQBWc2L3iQBzA9H32U5PtAUCe
VJwDDeQcwKRSIEE7JAJAiluyQDg8HsD8PLU3jz8CQOHNNbvi8R7AVCdKLuNa
AkA4Y5kkbK4fwAX8cxuLkQJAxUmHTd2eIMBe5ggS36wCQIgdLO+xCCHAttCd
CDPIAkAB7kEY23YhwGalx/Xa/gJA0wMPwUZhIsC+j1zsLhoDQOxuEZcm3iLA
Fnrx4oI1A0AP/OABl2AjwMZOG9AqbANAN/mtQLh3JMAeObDGfocDQFHwVzZI
DSXAdiNFvdKiA0BFFkRYKaolwCb4bqp62QNAfkRtQyH8JsB+4gOhzvQDQFLQ
tEV/sifA1syYlyIQBEAKbboJwXIowJ1WVZYEIgRAZ0ktEGL7KMA3i9XE
      "]], 
     LineBox[CompressedData["
1:eJwV1ms4FAgXB3AZxmDG3McwgzHuQ5IprCz/sLQGM+u2r0tUK1KK8CqiEqIS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      "]]}, 
    {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwVk2k81fn7h885HNnKsXYiW5YkW2kxkftrTylRaCpLyKjpZ19KWpSRVBqh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      "]], 
     LineBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAcacnJiaIBEBB792H87guQOZKFl8a
tARADiG+vNnPLUA+NatVbs8EQNlBrjOSSC1Alh9ATMLqBEB1tbRiKscsQEf0
aTlqIQVAzi5/dYLUK0Cg3v4vvjwFQHiAPcGZYitA+MiTJhJYBUCjoq8NPvUq
QKidvRO6jgVAinLIICEnKkAAiFIKDqoFQP6jYUrmxSlAWHLnAGLFBUBlEu5K
RGgpQAhHEe4J/AVAG5NetQW3KEBgMabkXRcGQKEURTQPYyhAuBs727EyBkBX
aNUb/REoQGjwZMhZaQZAFbOhNvJ3J0DImbiiqdYGQDupjme3YCZAUr83TEjb
BkBNHwV3rlUmQNzktvXm3wZAtAg6W7RKJkDvL7VIJOkGQP725SrsNCZAFsax
7p77BkD8Xa23CAomQGXyqjqUIAdAYAcCAt22JUACS53SfmoHQFAa1YM8GiVA
OQUvp+DlB0CMj40OTi4kQG4FkB0=
      "]], LineBox[CompressedData["
1:eJwVlnk0FAobxtFyMWP2GcwwZswYkSQjXEkPV1KEiO9D0SJbinCtbVNE5aor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      "]]}, 
    {RGBColor[0, 0, 1], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQne6pK5D0W+MAjI5rmSJ6foU6nK5LYF7HLawGpxl0
5fc7t6rA6VvdM9tXX1WC0zJcGSu/OCnC6WxTLdbbMvJwOtn83orDh6XhtFaF
1f+8JRJweuHd4COVjqJw+nmjqI27hBCc3jVVw/VFGC+cNnh584v+XDY47bLr
NuffMAY4XbBy/Q9B4c/7YXRYmvLCSzU34fTxMze7jINv2MNoK92DmwKmf4bT
HH9+hTN/+A+nAc5Rk18=
      "]], 
     LineBox[{{2.0039030612244897`, 2.0039030612244897`}, {
      2.8548157417855897`, 2.8548157417855897`}, {2.9872448979591835`, 
      2.9872448979591835`}}], 
     LineBox[{{3.0127551020408165`, 3.0127551020408165`}, {3.782818516377418, 
      3.782818516377418}, {4.630862909846669, 4.630862909846669}, {
      5.422500527346527, 5.422500527346527}, {6.198547695407606, 
      6.198547695407606}, {7.040637067091129, 7.040637067091129}, {
      7.82631966280526, 7.82631966280526}, {8.678044462141836, 
      8.678044462141836}, {9.473362485509021, 9.473362485509021}, {
      10.253090059437424`, 10.253090059437424`}, {11.098859836988273`, 
      11.098859836988273`}, {11.888222838569732`, 11.888222838569732`}, {
      12.743628043773633`, 12.743628043773633`}, {13.583442799538753`, 
      13.583442799538753`}, {14.366850779334484`, 14.366850779334484`}, {
      15.216300962752658`, 15.216300962752658`}, {15.361232992021202`, 
      15.361232992021202`}}]}, {}}, {{}, {}, {}, {}, {}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-20, 20}, {-12.49098253777329, 15.361232992021202`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.535160548231447*^9, 3.5351605645715837`*^9}, {
   3.535160600132503*^9, 3.535160628655446*^9}, {3.535161099795094*^9, 
   3.535161120904355*^9}, 3.5351624213048162`*^9, 3.535231905982996*^9, 
   3.5354188577275677`*^9}]
}, Open  ]],

Cell[TextData[{
 "We consider some points on the graphs. From the calculations below, we have \
that f(10) = ",
 Cell[BoxData[
  FormBox["3", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". Also since  the relationship f(x) = y implies that ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontColor->GrayLevel[0]],
 "(y) = x, we should have ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontColor->GrayLevel[0]],
 "(",
 Cell[BoxData[
  FormBox["3", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") = 10. This is borne out by our calculations below. \nTherefore we must \
have the point (10, 3) on the graph of y = f(x) and the point (3, 10) on the \
graph of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", " ", "=", " ", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]],
  FontColor->GrayLevel[0]],
 "(",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],
  FormatType->"TraditionalForm"],
 "). "
}], "Text",
 CellChangeTimes->{{3.5351599798373003`*^9, 3.5351600133504047`*^9}, 
   3.535160649889956*^9, {3.535160977639585*^9, 3.535160989163604*^9}, {
   3.535161140988937*^9, 3.535161505358333*^9}, {3.535161539932485*^9, 
   3.535161554842329*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", "10", "]"}]], "Input",
 CellChangeTimes->{{3.535161514332246*^9, 3.535161524610385*^9}}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{3.5351615299163427`*^9, 3.535231925039267*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"finv", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.535161567392639*^9, 3.535161571223031*^9}}],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{3.535161575137805*^9, 3.535231929139942*^9}]
}, Open  ]],

Cell["\<\
We plot these points on the graphs and show how they are refelections of each \
other in the line x = y. \
\>", "Text",
 CellChangeTimes->{{3.535161588574383*^9, 3.535161650256297*^9}, {
  3.535162385904298*^9, 3.535162392880003*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "x"}], "+", "1"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "-", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"finv", "[", "x_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"3", "x"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", " ", "-", " ", "2"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dots", ":=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"10", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "10"}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basicplot", ":=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"finv", "[", "x", "]"}], ",", "x"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "12"}], "}"}], ",", 
     RowBox[{"Exclusions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Green", ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", " ", "Dashed"}], "}"}]}], "}"}]}], ",", "  ", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L", ":=", 
   RowBox[{"Line", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"10", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "10"}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"basicplot", ",", " ", "dots", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", "L"}], "}"}], "]"}], ",", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<(10, 3)\>\"", ",", " ", 
      RowBox[{"{", 
       RowBox[{"9", ",", " ", "3.2"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<(3, 10)\>\"", ",", " ", 
      RowBox[{"{", 
       RowBox[{"3.3", ",", " ", "9"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.535161679347124*^9, 3.5351617870660963`*^9}, {
  3.5351618210284643`*^9, 3.5351618600514793`*^9}, {3.535161909873713*^9, 
  3.535161921766597*^9}, {3.535162312468606*^9, 3.535162364330081*^9}, {
  3.535418836302911*^9, 3.53541883748417*^9}, {3.5354189462067137`*^9, 
  3.535419001177928*^9}, {3.53541903423127*^9, 3.535419061763208*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwVlPk/FPgfgEdumcjUGh3WsRmKVlkkx3tVW3J0UCidJLnvtI5V6aSyjaLY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       "]], LineBox[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAAqmoo/f8HAEBdjhUSHBwUwII+GG9g
CwBAeYDgdQooFMCf7tr4ChYAQIXHgUr9TRTA2E5gDGArAEAj21AYGZsUwEoP
azMKVgBAu6T+e1g6FcAvkICBXqsAQMNalEWQjhbATEBDCwm2AED3yLtUR7sW
wGjwBZWzwABABXdWAoLoFsCiUIuoCNYAQCaldWiLRBfAFBGWz7IAAUCoRmu9
MQMYwPiRqx0HVgFADHYn/RmdGcAUQm6nsWABQNRMLsM90xnAMfIwMVxrAUBS
nUMKEQoawGpStkSxgAFAECX1nNN5GsDcEsFrW6sBQC4XM1gsYhvAwZPWua8A
AkB/wVw6m1kdwN5DmUNaCwJAsbJzZ3+cHcD681vNBBYCQDBkGN1U4B3ANFTh
4FkrAkD5OqtS6GoewKYU7AcEVgJAgz87wUqMH8CKlQFWWKsCQCWgrCmsAiHA
xPV+zui2AkCrmJFVpDAhwP1V/EZ5wgJAullMZWdfIcBwFvc3mtkCQDk1Wotj
vyHAVpfsGdwHA0Ax8JNO1IkiwJD3aZJsEwNAMZ7fycK+IsDJV+cK/R4DQGDo
PzGs9CLAPBji+x02A0Dt/eArjGMjwCGZ191fZANA7Y0mPldOJMBa+VRW8G8D
QAvKsd7xiyTAlFnSzoB7A0ARhXPkx8okwAYazb+hkgNAl6e7vUxMJcDsmsKh
48ADQGGBi/veXybAvYf9linHA0CdER6TQIcmwHMi67I=
       "]], 
      LineBox[CompressedData["
1:eJwVVHk4lAsfVWmIMfOafbHMmOGVyAiVunFulpAkFSVtZLtylUJKZecTSRv1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       "]]}, 
     {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwVyWk8FGobgHFD1uxDlOXY5URSJMJNSgidLIdSKsmhQkUISSiZdiRLyFLh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       "]], 
      LineBox[CompressedData["
1:eJwBAQL+/SFib1JlAgAAAB8AAAACAAAA9eDuudf5A0B2K4JE+RYxQLicrWVn
HQRA87YtgvWbMEDy/Cre9ygEQEohVZAgdjBAK12oVog0BEA2v8qxG1EwQJ4d
o0epSwRAZmuL7GcJMECEnpgp63kEQEQwbpNeBS9Avv4VonuFBED5uzqxX8Uu
QPdekxoMkQRAcKdd7qSGLkBqH44LLagEQOfFIAzWDC5AT6CD7W7WBECpi5h2
3iYtQIgAAWb/4QRANFwjYQnwLEDCYH7ej+0EQMBngqQ1uixANCF5z7AEBUAs
pk1pdlEsQBqibrHyMgVABce12uOKK0Dmo1l1do8FQH3uN152JCpAHefuwzWZ
BUCv1jemZAEqQFQqhBL1ogVAahqROMzeKUDBsK6vc7YFQIA25Ij9milAnL0D
6nDdBUBpAfV2qBgpQFPXrV5rKwZA0g92LUwnKECKGkOtKjUGQG0CoP/KCihA
wF3Y++k+BkAYHyDKou4nQC7kAploUgZAwaIE2la3J0AK8VfTZXkGQHCWrQCm
TCdAwAoCSGDHBkB/HyUtpoUmQPdNl5Yf0QZAIjVgTwZuJkAukSzl3toGQKnF
6qCpViZAmxdXgl3uBkCYqyNktSgmQHYkrLxaFQdAdeTjv8PPJUAtPlYxVWMH
QIhazcvgKCVABS+n4OX0B0CwdsbSiBMkQEQF0FU=
       "]], LineBox[CompressedData["
1:eJwVlXk4lQkbxo1pOOQ9zr7ZjmN5o41Ie90SUoo2SigpVHx0lCgqUQwt2omO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       "]]}, 
     {RGBColor[0, 0, 1], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQrbh4+4v//4UPwGg2y2UKK38h6DfnpkQEfUXQ234V
nljyCkF7Bems8LyKoEsYF6ZPXoWgT8R3PVMLRdD5MrFPfFcJwWmlSWs47pkL
wmmHilzur7v54fTjFMc3+0V54bS/V6YcvxkXnA6cwcZU3s4Op2XufzdLns8C
p/v3rQh6eIQRThvyzrP/YPZvP4y+1jepRq3wB5xe8bBQpo/3M5yeeHqBsHHX
azj9Zdta42jhB3D6mJBj2ozmo3B6h+bXN9/unrCH0R/KeL7OnPkQTkswsmUG
m7+B03xXrp+uvfsZTidfc2xQsP0Jp9WfM0/axf8fTsuuPpXN+AFBAwBfUuPW

       "]], 
      LineBox[{{2.0039048947704083`, 2.0039048947704083`}, {
       2.3336645812257233`, 2.3336645812257233`}, {2.6950501602154757`, 
       2.6950501602154757`}, {2.994579081632653, 2.994579081632653}}], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQ/ftChLwUN4cDjG6ZXZGjuYwLTt9c775IopUXTp9e
GzC5XFIATru1X16j0CsIp3OnfLvE8EsITnu+jVsQ4icCpw96yrqm7ReF028/
Kkx8LS4Op4+dPfJyeaYEnLZau09S6YYknE6+8fcDv540nNZgnzx/9wIZOL2w
MffrrV+ycPq4/otwQz95OH2k4M4JpXgFOF2fn77zGZcinGYvmDuV8yiCTutS
/nG8WglOz/fy0XNQU4bTy3gUAsTvI+j2kmmuK7pV4LTdt5iDV0xU4fThynMa
CW8QtNLiR8lLp6vBaf9zC7s8A9XhdMw2jxSWEASdNe+97f4wBN2SZ/vRJAZB
7+C7Ga6QjqAV/AVUv9cg6A/n6/YvWYGg/25XnRm/GkFzLThTJLUOQasUSKlN
2IygIwS29VTvQ9AHAt5GBl1B0GctphjzXkfQtxSseU/cRNBfPnQcsL2PoDUm
qqhrvkLQppWnGZ68QdBOiUW35r1H0DGGB3pFviLoTMn09PPfEXQZI59j1y8E
3fxyi5TrXwQ94WL0l///ETQA78hJtw==
       "]]}, {}}, {{}, {}, {}, {}, {}}}, {{}, 
    {Hue[0.67, 0.6, 0.6], PointBox[{{10., 3.}, {3., 10.}}]}, {}}, 
   {Dashing[{Small, Small}], LineBox[{{10, 3}, {3, 10}}]}, 
   InsetBox["\<\"(10, 3)\"\>", {9, 3.2}], 
   InsetBox["\<\"(3, 10)\"\>", {3.3, 9}]},
  AspectRatio->Automatic,
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-5, 12}, {-11.26416454069186, 17.08974102189992}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.535419065544869*^9}]
}, Open  ]],

Cell["", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise", "Subsubsection",
 CellChangeTimes->{{3.535162605444191*^9, 3.5351626070976458`*^9}, {
  3.5351629839880323`*^9, 3.535162987224568*^9}}],

Cell[TextData[{
 "Use the formula you found for the inverse function of  Q(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"2", "x"}], 
    RowBox[{"x", " ", "+", " ", "4"}]], TraditionalForm]]],
 " above to graph y = Q(x), y = Q",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) and y = x on the same set of axes. Evaluate Q(4) and show that the \
point (Q(4), 4) is on the graph of y = Q",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x). "
}], "Text",
 CellChangeTimes->{{3.535162618379385*^9, 3.535162708954995*^9}, {
  3.5351627477076406`*^9, 3.535162884391596*^9}, {3.5351629396880817`*^9, 
  3.535162950372398*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Realtionship between derivatives of ",
  FontColor->GrayLevel[0]],
 StyleBox["f and ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{" ", 
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]]}],
    FontColor->GrayLevel[0]], TraditionalForm]]],
 StyleBox[". ",
  FontColor->GrayLevel[0]]
}], "Subsection",
 CellChangeTimes->{{3.535163233139093*^9, 3.535163285879572*^9}, {
   3.535230962842079*^9, 3.5352309813579407`*^9}, 3.535231239450307*^9}],

Cell[TextData[{
 "We have the following relationship between the derivative of f and its \
inverse function:\nFor any x in the domain of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", such that  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) is in the domain of f and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "'"}], "("}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x)) \[NotEqual] 0, we \nhave \n"
}], "Text",
 CellChangeTimes->{{3.5352325873434467`*^9, 3.5352326184825363`*^9}, {
  3.5352327971369867`*^9, 3.535232910184937*^9}, {3.535232954838365*^9, 
  3.535233090789909*^9}, {3.535233170023941*^9, 3.535233178262957*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(x) =  ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["f", 
        RowBox[{"-", "1"}]], "(", "x", ")"}], ")"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "    or    ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(x) =  ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     RowBox[{"f", " ", "'"}], 
     RowBox[{"(", "y", ")"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "     where   y = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) "
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.5352331049375477`*^9, 3.535233259933713*^9}, {
  3.535233289952834*^9, 3.535233354731151*^9}, {3.5352397132461367`*^9, 
  3.5352397132462273`*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell["Example:", "Subsubsection",
 CellChangeTimes->{{3.5352338406532497`*^9, 3.53523384458538*^9}}],

Cell["\<\
We return to our example above and check this out for some specific numbers.  \
From above, we have \
\>", "Text",
 CellChangeTimes->{{3.5352338503788843`*^9, 3.535233885495763*^9}, 
   3.535233931021913*^9, {3.535234030605678*^9, 3.53523403691733*^9}}],

Cell[TextData[{
 "f(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", "x"}], " ", "+", " ", "1"}], 
    RowBox[{"x", " ", "-", " ", "3"}]], TraditionalForm]]],
 ",    then     ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "x"}]}], 
    RowBox[{"x", "-", "2"}]], TraditionalForm]]],
 "     and     10 = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(3) "
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.535233938927763*^9, 3.535233949981876*^9}, {
  3.535234017016786*^9, 3.535234070043867*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "According to the above formula, we should have that   ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(3) =  ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "10", ")"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "  .\nTo check, we calculate the derivatives of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ".\n"
}], "Text",
 CellChangeTimes->{{3.535234181477108*^9, 3.535234195986149*^9}, {
  3.5352343382781267`*^9, 3.535234416335122*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "x"}], "+", "1"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "-", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"finv", "[", "x_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"3", "x"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", " ", "-", " ", "2"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], ",", "x"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5352344453023863`*^9, 3.5352344489268503`*^9}, {
  3.535234499979702*^9, 3.535234504449606*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["7", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", "x"}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{3.5352345155677643`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"finv", "[", "x", "]"}], ",", "x"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.535234522097101*^9, 3.535234528030601*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["7", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "x"}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{3.535234532243226*^9}]
}, Closed]],

Cell["Thus, we have", "Text",
 CellChangeTimes->{3.5352347457608147`*^9}],

Cell[TextData[{
 "  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(x) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    FractionBox[
     RowBox[{"-", "7"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "2"}], ")"}], 
      FormBox[
       SuperscriptBox["", "2"],
       TraditionalForm]}]]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "      and        ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "f"}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"-", "7"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "3"}], ")"}], 
     FormBox[
      SuperscriptBox["", "2"],
      TraditionalForm]}]], TraditionalForm]]],
 ". "
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.5352345459734507`*^9, 3.535234698014538*^9}, {
  3.535234733361912*^9, 3.5352348060519543`*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "To check if   ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(3) =  ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "10", ")"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "  we define the functions in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as  finvprime := ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and fprime :=  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "f"}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and evaluate (or we evaluate by hand which might be easier here ). "
}], "Text",
 CellChangeTimes->{{3.535234900646028*^9, 3.5352350140494204`*^9}, {
  3.535235113288458*^9, 3.535235160707305*^9}, {3.535239601159561*^9, 
  3.53523960199823*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"finvprime", "[", "x_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"-", "7"}], "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", "2"}], ")"}], "^", "2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fprime", "[", "x_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"-", "7"}], "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", " ", "-", "3"}], ")"}], "^", "2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"List", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"finvprime", "[", "3", "]"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"fprime", "[", "10", "]"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.535235072155525*^9, 3.535235132425187*^9}, {
  3.535235205869259*^9, 3.535235263695299*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"-", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"-", 
     FractionBox["1", "7"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.535235268812233*^9}]
}, Closed]],

Cell["The result is as predicted.", "Text",
 CellChangeTimes->{{3.535235284341364*^9, 3.535235304465908*^9}, {
  3.535238703795854*^9, 3.535238704995307*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise", "Subsubsection",
 CellChangeTimes->{{3.5352393232569847`*^9, 3.535239325662537*^9}}],

Cell[TextData[{
 "Find the derivative of the function  Q(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"2", "x"}], 
    RowBox[{"x", " ", "+", " ", "4"}]], TraditionalForm]]],
 " and  use the formula you found above for its  inverse function Q",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) to find a formula for (Q",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["", 
      RowBox[{"-", "1"}]], ")"}], "'"}], TraditionalForm]]],
 "(x).  Verify  that, 4 = Q",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(1) and show that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["Q", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(1) =  ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     RowBox[{"Q", " ", "'"}], 
     RowBox[{"(", "4", ")"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " ."
}], "Text",
 CellChangeTimes->{{3.535239334371533*^9, 3.535239650569007*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Realtionship between Tangents to the graphs of f and ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{" ", 
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]]}],
    FontColor->GrayLevel[0]], TraditionalForm]]],
 StyleBox[". ",
  FontColor->GrayLevel[0]]
}], "Subsection",
 CellChangeTimes->{{3.535239748512085*^9, 3.535239764121756*^9}}],

Cell["\<\
We saw above that the derivatives of f and its inverse function is given by \
\>", "Text",
 CellChangeTimes->{{3.535239781882245*^9, 3.53523980952599*^9}}],

Cell[TextData[{
 "  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(x) =  ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     RowBox[{"f", " ", "'"}], 
     RowBox[{"(", "y", ")"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "     where   y = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) "
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.5352331049375477`*^9, 3.535233259933713*^9}, {
  3.535233289952834*^9, 3.535233354731151*^9}, {3.5352397132461367`*^9, 
  3.5352397132462273`*^9}, {3.535239852278989*^9, 3.5352398620119333`*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "If (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["y", "1"], ")"}], " ", "is", " ", "a", " ", "point", " ", 
    "on", " ", "the", " ", "graph", " ", "of", " ", "the", " ", "function", 
    " "}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ", then the slope of the tangent to the curve y = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x)\nat that point is given by   ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ").  Recall that the point (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") must be on the curve y = f(x) \n(since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 ") if and only if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"  ", 
    SubscriptBox["x", "1"]}], TraditionalForm]]],
 " = f(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]]],
 "). The slope of the curve y = f(x)  at the point (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") is given by \n ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{
     RowBox[{"(", 
      SubscriptBox["y", "1"], ")"}], ".", " "}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\nThe formula  above says that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") =  ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     RowBox[{"f", " ", "'"}], 
     RowBox[{"(", 
      SubscriptBox["y", "1"], ")"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", that is",
 StyleBox[" the slope of the tangent to the graph of y = ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontWeight->"Bold"],
 StyleBox["(x) at the point \n (",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontWeight->"Bold"],
 StyleBox[", ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["y", "1"], ")"}], " ", "is", "  ", "the", " ", "inverse", 
    " ", "of", " ", "the", " ", "slope", " ", "of", " "}], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontWeight->"Bold"],
 StyleBox["the tangent to the graph of y = f(x)  at the point (",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontWeight->"Bold"],
 StyleBox[", ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontWeight->"Bold"],
 StyleBox[").\n\n",
  FontWeight->"Bold"],
 "We demonstrate this graphically for  our example. \n"
}], "Text",
 CellChangeTimes->{{3.535239871227944*^9, 3.535239877377387*^9}, {
  3.535240075327519*^9, 3.535240885599332*^9}}],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
 CellChangeTimes->{{3.535240931926826*^9, 3.535240933516385*^9}}],

Cell["We have the following", "Text",
 CellChangeTimes->{{3.535240952629347*^9, 3.5352409566667137`*^9}}],

Cell[TextData[{
 "f(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", "x"}], " ", "+", " ", "1"}], 
    RowBox[{"x", " ", "-", " ", "3"}]], TraditionalForm]]],
 ",    then     ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", "x"}]}], 
    RowBox[{"x", "-", "2"}]], TraditionalForm]]],
 "   ,     10 = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(3) ,    3 = f(10),     ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(3) = -7,    f\[CloseCurlyQuote](10) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"-", "1"}], "7"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.535233938927763*^9, 3.535233949981876*^9}, {
  3.535234017016786*^9, 3.535234070043867*^9}, {3.535240962939932*^9, 
  3.535240990514076*^9}, {3.535241036516492*^9, 3.535241079158147*^9}},
 TextAlignment->Center,
 Background->GrayLevel[1]],

Cell[TextData[{
 "The equation of the tangent to the graph of y = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 "(x) at the point (3, 10) is given by \nTfinv(x) =  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 "(3) +  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(3) (x - 3) = 10 - 7(x - 3).\nThe equation of the tangent to the graph of y \
= ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FontWeight->"Plain"],
 "(x) at the point (10, 3) is given by \nTf(x) =  ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FontWeight->"Plain"],
 "(10) +  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "f"}], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "'"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(10) (x - 10) = 3 + ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    FractionBox[
     RowBox[{"-", "1"}], "7"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ")(x - 10) . \nWe graph these tangents along with the graphs of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 " below. The tangents are shown in blue. The graph of y = ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FontWeight->"Plain"],
 "(x) is shown in red and the graph of the inverse function in green. We see \
that that, the graphs of these functions  are reflections of each other in \
the line y = x. The tangent at a point (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") on the graph of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is the reflection through the x-axis of the tangent to the graph of  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 " at the point  (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ").  Therefore the slopes are reciprocals of each other. "
}], "Text",
 CellChangeTimes->{{3.5352411558879004`*^9, 3.5352414017900343`*^9}, {
  3.535241524951749*^9, 3.535241679916954*^9}, {3.535241861937805*^9, 
  3.535241897077545*^9}, {3.535242007462962*^9, 3.535242194818576*^9}, {
  3.5352422363223133`*^9, 3.535242385046084*^9}, {3.535242482134935*^9, 
  3.53524250808711*^9}, {3.535242833214902*^9, 3.5352428352685328`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "x"}], "+", "1"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "-", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"finv", "[", "x_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"3", "x"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", " ", "-", " ", "2"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tfinv", "[", "x_", "]"}], ":=", " ", 
   RowBox[{"10", " ", "-", " ", 
    RowBox[{"7", 
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", "3"}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tf", "[", "x_", "]"}], " ", ":=", " ", 
   RowBox[{"3", " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "7"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", "10"}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dots", ":=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"10", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "10"}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basicplot", ":=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"finv", "[", "x", "]"}], ",", "x", ",", " ", 
       RowBox[{"Tf", "[", "x", "]"}], ",", " ", 
       RowBox[{"Tfinv", "[", "x", "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "20"}], "}"}], ",", 
     RowBox[{"Exclusions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Green", ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", " ", "Dashed"}], "}"}], ",", " ", "Blue", ",", 
        " ", "Blue"}], "}"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L", ":=", 
   RowBox[{"Line", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"10", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "10"}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"basicplot", ",", " ", "dots", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", "L"}], "}"}], "]"}], ",", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<(10, 3)\>\"", ",", " ", 
      RowBox[{"{", 
       RowBox[{"9", ",", " ", "3.2"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<(3, 10)\>\"", ",", " ", 
      RowBox[{"{", 
       RowBox[{"3.3", ",", " ", "9"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.535241508539215*^9, 3.535241510843029*^9}, {
  3.5352416929739943`*^9, 3.535241821629072*^9}, {3.535241925960586*^9, 
  3.535241932359787*^9}, {3.535241986684729*^9, 3.535241988740055*^9}, {
  3.535242741488921*^9, 3.535242745482977*^9}, {3.5352428080252333`*^9, 
  3.53524282342974*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwBoQRe+yFib1JlAgAAAEkAAAACAAAAnX5iBjFkmz49LDSqVlXVv8TTIExX
IHk/sPB/EKqj1b//xr6DICCJPzvGA8xP8tW/ncCNHwUgmT+W1xxMlJDWv2w9
dW33H6k/8cYm7w/R17/T+2iU8B+5P/sbYWJJYtq/B9viJ+0fyT9Y0V3cwMnf
v9jAvXXs6Mk/c3sXtLgR4L+qppjD67HKP7EzKG7DPuC/TnJOX+pDzD/Ev9iU
cZngv5YJupbnZ88/Jm+9MTpR4b8SnMgC8dfSP7em42rLyuK/ocqfcesf2T8U
HiBckOjlv/SYtSrfjNk/NHwp6Msg5r9GZ8vj0vnZP9xlIUJRWea/7AP3VbrT
2j+rjw+oO8vmvzg9TjqJh9w/pIx0ip+y57/Qr/wCJ+/fP+qDz1ErkOm/f8os
SjFf4z+TKRqY6ortv6ixtyarleM/omnFMprN7b/SmEIDJczjP9UW4yWpEO6/
JGdYvBg55D+9W/xL6Jfuv8oDhC4AE+U/VsImmAKr778WPdsSz8bmP2xn8pwz
8vC/rq+J22wu6j/Xih60PlXzv+oS6oxKYeo/asAXAsB6878ndko+KJTqPwZW
GkZ4oPO/oDwLoeP56j81xUOWj+zzv5LJjGZaxes/mgSk8GaH9L9244/xR1zt
PyPzJjcqyPW/nwvLgxFF8D9dEcPA5Xn4vz49e1yAXvA/6igzuE6n+L/cbis1
73fwP1BrzPAA1fi/GNKL5syq8D9p0ALvQzH5v5GYTEmIEPE/kFSMIljt+b+D
Jc4O/9vxP4NW1mhhdPu/Zz/Rmexy8z8T8FXXw8P+vwCi9rrbi/M/ZLJyGsT6
/r+YBBzcyqTzP0yDhxclMv+/yMlmHqnW8z/JeUtDDaL/vyhU/KJlOvQ/AhJ5
oklDAMDoaCes3gH1PyJmX8i0MQHAgMtMzc0a9T+Z8qbWelABwBgucu68M/U/
7eEzKXpvAcBI87wwm2X1P+8/NB8nrgHAqX1StVfJ9T+U0G9xTC4CwGqSfb7Q
kPY/qaBHGV46A8AC9aLfv6n2PxxptBYJXQPAmlfIAK/C9j9wMlKT+H8DwMoc
E0ON9PY/zql1PKjGA8Arp6jHSVj3P3Zzt2NhVwTA7LvT0MIf+D8mWsf9/oYF
wG7lKeO0rvk/XVVnX9QlCMDJRadf88f5Pz7ni4txUwjAJKYk3DHh+T/QEg3U
doEIwNtmH9WuE/o/Twi6WL/eCMBI6BTHqHj6P2zRz/dwngnAIuv/qpxC+z9M
PoIJtDMLwH1LfSfbW/s/NlA9AopoC8DYq/qjGXX7P/8FM9bhnQvAj2z1nJan
+z+yQEidHgoMwPzt6o6QDPw/SiCYnQPpDMDW8NVyhNb8P1gmGgNVwg7AMVFT
78Lv/D/s0/JOQAAPwIyx0GsBCf0/pfoictA+D8BDcstkfjv9P2HoP6PpvQ/A
sPPAVnig/T8WKozIJWIQwIr2qzpsav4/ZDUj2C96EcDlVim3qoP+P4UfeO73
nhHAQLemM+mc/j/zGwbTKsQRwPd3oSxmz/4/hCb9YNgPEsBk+ZYeYDT/P1gY
fnKIrBLA+PWvBgDw/z+jjbjvG+QTwBDMbGA=
       "]], LineBox[CompressedData["
1:eJwBcQOO/CFib1JlAgAAADYAAAACAAAABAWo/P8HAECHolAQHBwUwKAdzAZ1
DQBA2TqHWGkvFMBeOdkOFBoAQFPWY5NzXBTA2nDzHlIzAECAoplWPbgUwNLf
Jz/OZQBAVYn9evV2FcDCvZB/xsoAQD2r66i0ExfAgNmdh2XXAEAXHjU6f0oX
wD71qo8E5ABAKAR9VgyCF8C6LMWfQv0AQONLz5p+8xfAspv5v74vAUAPz/Dk
POAYwKN5YgC3lAFAb4D8Hl3lGsBilW8IVqEBQBEZtt+BKhvAILF8EPWtAUDJ
097EunAbwJzoliAzxwFANiFsPoMAHMCUV8tAr/kBQL4UZ8QyLh3AUnPYSE4G
AkAN5iQtu3wdwBCP5VDtEgJA0OTQGZLMHcCMxv9gKywCQPka8HRNcB7AhDU0
gadeAkAPb3KT+MgfwEJRQYlGawJAbR4/13gRIMAAbU6R5XcCQCrP661CPyDA
fKRooSORAkDRNmGRVJ0gwHQTncGfwwJA16zodBlkIcBl8QUCmCgDQJmDmW43
IiPAkBhYjEU2A0AO00pwTWQjwLw/qhbzQwNAUKMtSOGnI8ASjk4rTl8DQNas
bWG3MyTAwCqXVASWA0C8Tzdms18lwOtR6d6xowNAORs5nUqvJcAWeTtpX7ED
QJwYqlTbACbAbcfffbrMA0CZ7mJuNqomwBpkKKdwAwRAdGuVWSkYKMBFi3ox
HhEEQCZo4NzceSjAcLLMu8seBEABQExEQd4owMcAcdAmOgRAu+ky0ZGvKcDy
J8Na1EcEQHJgzLO8HCrAHk8V5YFVBEBCi4IzFo0qwHSdufnccARAYQBxyed3
K8CgxAuEin4EQAoFn9au8ivAy+tdDjiMBEACnHHHQnEswCI6AiOTpwRAMimI
yIt6LcDP1kpMSd4EQF7OAJxtwy/A+v2c1vbrBEDGq8BQKzEwwCYl72Ck+QRA
1mqCZW6DMMB8c5N1/xQFQEtbQCj+MDHAqJrl/6wiBUDyeJQkoYwxwNPBN4pa
MAVAub3j3r/rMcAqENyetUsFQOFon/lDtTLAVTcuKWNZBUAmUGe3HSAzwIBe
gLMQZwVARolIzlyPM8DXrCTIa4IFQAlyW7ssfDTAAtR2UhmQBUArMVZMXvo0
wC77yNzGnQVAEUFtGDh+NcCPqboiXJ4FQOtCkVg8hDXA6O525A==
       "]], 
      LineBox[CompressedData["
1:eJwV1mlYDGobB/A0UzFbM9Ms1Uz7tGthFK3+bSSkoiTRK21akJZToTpFIZIo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       "]]}, 
     {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwViXk01AkcwAeVKHKUO4MwGESl2hzfojRJtR1iYykvV4vSNgo5eipnYVLL
RjHamA5Sq3Lk910Ro+Tqkrsp7DjHHMxM2PaPz/u8z/sY+p88ECBLIpGO/OB/
58f5L7E9ftMp5kl0vAxpgKjvNHD3NIiCDhNH+kavAWLhVW2igUEK9NYkN4ke
DRD5eIW82CAXis11K/WPDxKhjvSwGTILMhV6Ftu2fyE6pcHZU+RKsFsf8vGP
xm+EfPcXyjiZDR71cS9sbcaIT/iCPjbChgMhnzVL88aIe3dzXo6WN8PLpNHC
EYVxYu/pvX5clzegyTu7pmBonLihUHVjOKgVGrIY0ftZk4RaXpMs72MHsEWR
YS33eERh8+2IUXIXiORMPTY8FBKCnAqL/vQuYEZMMPfMCAnXoNecDnEX2Gsk
r1/sLCLG5GY8qjo/Q0PRYR3PLhGx2XHvlpSkHjhTHPOOWDFLtJV9l6VM9kN7
n9pvjHwJoQYKvkrWA0CJxPuMaQlhb5q9Jen4AHBeyZzxoEmJqwIWP7p9AE60
xhlZiaTEhqz3Af73B2Fg4YhfhPccEd9s6Wbrx4F/qRZm4RQSlpQ/M71/nQPP
9S7JlXqRsCPHWc7kDQecPakuQakkNA7yqtH66SsMRagu2jNJwma5i9Yk9W9Q
7XZppTYhgxqO3Wqtr4bg0WVB/slzclhaltIdas0FkqP0xj5/eeSqcdPdjnFh
jhq4cJQpj5RINyezbC5U9ylmG3DkscBhWSFHzIWmirioisClyGCnBx5pGIUH
jwKoyZEKGMnJ4O30GQehbhEtt3oZPnadYppkjEMYbfEgaelynGT9fEiubhyG
8inndnssx+BTqs9qKROg6JlWkDu9HI/MMc7b8Seg4bqVVcZmZby97HWi6o4p
uOOt78uLVkEnxxifBN8p6FKpjKKxVLAnnGo3eXYKJucdftn0SQW1OtKG3tyb
gsvxn21GNqliVo77rmQVHiheKN42Pq+KiSZvlRe6efAkodf+cqk6GnnGDYcJ
eSD/60TnyLA6YrI19ihPQ9FdX7ae0Ur8Pno1omrbNAS2PBcq5q5E+uN97+jF
07BRYV4+KWsVBkF77thpPgzm/cV8Uq6JJKaoqjuND7jcjGUh1sScRXo9zXf4
4PClRbdumxY2sQP1WR/4sNB8bS7sgxaaHfrODNgigLKnh64lK+sgPjWsP3RQ
AHi+/Pc2Px300t75zSVUAEO7myIiH+tgcl8WxeiWANTiq6tIPro4Ekx50Ccj
BMH2mAXdf/Qw4bV7S4uOEGYajfyO6q9GLevTEzXrhXBguDDmYOxqpPFrbG4G
/PgJpoH0rfrIij1Q4ckWwkBvaKVSLxlPMGJr2zJFoJLpyXSoNURZIbOfYIlg
q41f9J05Q/zTs4lUVicCWWftVH8nI2zWU3e5IhDBNjEjRaneCKnFJY27vGag
fTiEfmpwDdYrvB3ZHDEDG9fSsj9ZGqNPKF/BLHUGLp/NsJyLMsZ0Wyf3JTU/
eqtZUZW2CY5Vd7bVkWfhFn1wDfeUKV7UF/PKN89C6hqq/qo3pqh3QV+9cP8s
dHIk0gxzCrq7hnjEJ86C2Dy4uX2Ugg/b5rvsh2chRict62CmObquN5ZakMTg
WsdOqCdZYN/1XXo62mIgshU/Hztjgcre2b6zbmKgGTb4lAVQMfybOefvUjFo
dBT0TJyxQvaOYj9+oxjYuVWWPYus0fiucY/toBjGZgwbQ3OtsTuQ/L5UXQLV
SzSUAtrX4sbGvP3jlhJ4aTn28O4WG2RQdN5SXSXAvbE2MizDBmkjKxtLzkkg
b6rvmpKzLRbRGC7DWRKgPzfcbl9gi/MlK9DkvgQkjtOtX2XWYUWIYiWzVwKy
e0Llo9rWodHowr08Zynk0frdNxRuwNjdsZRubyl4Oxa8rjK0w5LD+8mB4VIY
dc7ycrhoh/8BIbPo7A==
       "]], LineBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAA9GGCeoxpAkBSSHWZLDc6QEJRQYlG
awJAF4JDNk4mOkAAbU6R5XcCQGUtzqrvrzlAfKRooSORAkAc6dWT1tA4QDrA
danCnQJA9C9kbJhnOED424KxYaoCQO66jec+AjhAdBOdwZ/DAkDyWbl1ZEI3
QDIvqsk+0AJAOFgNOYLnNkDwSrfR3dwCQCUF1FrBjzZAbILR4Rv2AkC2PuCg
A+k1QGXxBQKYKANAoymvecO6NECQGFiMRTYDQPsX9rhDbzRAvD+qFvNDA0Dy
z3p0PCY0QBKOTitOXwNAUDolIB+bM0DAKpdUBJYDQNi9hd7DnTJA61Hp3rGj
A0DzKZhGE2MyQBZ5O2lfsQNAagsJcRUqMkBtx999uswDQCok8LDovDFAGmQo
p3ADBEB3eOAIAPQwQEWLejEeEQRAZAj9gBLFMEBwssy7yx4EQPYSP4pclzBA
xwBx0CY6BECJJnoOaD8wQHSdufnccARArGMl0WM4L0CgxAuEin4EQCbALYii
6y5Ay+tdDjiMBEDNosjyrqAuQCI6AiOTpwRAViu9SfEPLkDP1kpMSd4EQMzX
CeaFAS1A+v2c1vbrBECBEpxylsEsQCYl72Ck+QRANuUWiwaDLEB8c5N1/xQF
QMe91QXZCSxAKhDcnrVLBUDxNcC7KSYrQFU3LiljWQVAx0XgphXwKkCAXoCz
EGcFQIIyzmQTuypA16wkyGuCBUBvy3p7JFQqQIRJbfEhuQVAqmqmrc6RKUCv
cL97z8YFQAo9t2l4YylA2pcRBn3UBUBceR2S+zUpQDHmtRrY7wVA+6jorHbd
KEDegv5DjiYGQHfdjxmnNShAObyPlvqTBkB9GYhZvgYnQECBOlSnmQZANpwb
wxr4JkBIRuURVJ8GQFSLXEOQ6SZAWNA6ja2qBkCkIqKHxcwmQHbk5YNgwQZA
Kr9zTFKUJkCyDDxxxu4GQFFXKM/AJyZALF3oS5JJB0BrLhPpd14lQDQikwk/
TwdAyadmY4lSJUA75z3H61QHQKT2I1atRiVASnGTQkVgB0C0bFb6Ky8lQGmF
Pjn4dgdAGpJOsP8AJUCmrZQmXqQHQBFcyP3dpyRAnYKXU/DyB0CClmL8ABck
QMM+WYo=
       "]], LineBox[CompressedData["
1:eJwV1Xk01PsbB3CmxfIdzHznOzPGMpgppJrkG9eSenctWVJoU6HSVcrWYpfd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       "]]}, 
     {GrayLevel[0], Dashing[{Small, Small}], 
      LineBox[{{4.0816326530612243`*^-7, 4.0816326530612243`*^-7}, {
       0.006134358411192534, 0.006134358411192534}, {0.012268308659119763`, 
       0.012268308659119763`}, {0.02453620915497422, 0.02453620915497422}, {
       0.04907201014668314, 0.04907201014668314}, {0.09814361213010096, 
       0.09814361213010096}, {0.19628681609693663`, 0.19628681609693663`}, {
       0.39257322403060796`, 0.39257322403060796`}, {0.8181671417091729, 
       0.8181671417091729}, {1.2155576714030418`, 1.2155576714030418`}, {
       1.605152976377521, 1.605152976377521}, {1.9960953443877552`, 
       1.9960953443877552`}}], 
      LineBox[{{2.003904655612245, 2.003904655612245}, {2.3948211820663112`, 
       2.3948211820663112`}, {2.822255302678539, 2.822255302678539}, {
       2.993622448979592, 2.993622448979592}}], LineBox[CompressedData["
1:eJxFxVtMEgAUAFC1LINZxkAmwxRUVEqwzCLQcqZt5dakNb+Qlik1oRhTnEhp
Smm1ZtjKXHPOkqWmFcqYYUWsD4tyNMvNHOZrtmUPUWQ8LKD66N6Ps8MokR8r
CwsJCcn569+nLpzp3xIZkfN/xqNDjlomER7I2Kp407QZNr2I6eyejIJ5K/5m
+WkSLL6pGdlIJcN0slFn7qXADeuuvMsXU+HGsMeqMUIMzJyvs6nv0mAJd1Xq
LqDDucUk/Y3ZWHjE+yHL1xoHu4QVPYb78fAY9WN4jZQBN9zSNKXkM+G60Gsi
SVQCXODep3wwgX+/xx+0PUmEJ7JbchtVSfAdLc+TdJwFs6RXHa/ZyXDonnSB
z4nrh5L7SKMpcH+q8tyz1lS4KkGmlBSzYfK4odO3ezscrBTG0QO4efTAK9an
HbCVfOmppSsN7lpQOEVSDiyU6gvnDnJhloJZv7YhHY6MoMiqK3F7yVS1ZwZ/
bzzK3Z+3E04rXfR49fgggVuujt4Fb1MeDgRUuIt/Xef+gi97VS7jkQy4iKQt
WhzCp87SBjaZ8JNWHZE9jMsumizlz3HN0jz7hwXXv80MLllxgsbe7bLj2umy
MMpnnMJfFmVO4/Er60lVs/jeE5zzngW8VFBfuPYT/9ZK7KM5cLnzdrhgGa/p
fTisduIt1PFEvxuPrhDXxXrxdtvXyWwf3nPZ31z7C+fMNS12/MYNWaS8l36c
19beMRPAzassXzCI/wGr7M+1
       "]]}, 
     {RGBColor[0, 0, 1], 
      LineBox[{{4.0816326530612243`*^-7, 4.42857137026239}, {
       0.006134358411192534, 4.4276950916555435`}, {0.012268308659119763`, 
       4.426818813048697}, {0.02453620915497422, 4.425066255835004}, {
       0.04907201014668314, 4.421561141407617}, {0.09814361213010096, 
       4.414550912552842}, {0.19628681609693663`, 4.400530454843294}, {
       0.39257322403060796`, 4.3724895394241985`}, {0.8181671417091729, 
       4.3116904083272605`}, {1.2155576714030418`, 4.254920332656708}, {
       1.605152976377521, 4.199263860517497}, {1.9960953443877552`, 
       4.143414950801749}}], 
      LineBox[{{2.003904655612245, 4.142299334912536}, {2.3948211820663112`, 
       4.08645411684767}, {2.822255302678539, 4.025392099617352}, {
       2.993622448979592, 4.000911078717201}}], LineBox[CompressedData["
1:eJwVxXswFHgAB3DWem6oHTIZKovFEssvIo/f94jrkqbHXbdN0hzSYxU7eW0O
xQmNior0oHWZk6jzOIVzOHXupNOoZrq8inQiJ23Cj3bd3R+f+ViFx2zfx9HQ
0MB//j8i5UCVsaEelGWmXwnUxrC6FfQuVcBDbXvVhd2njVFDlsn+yDKC2FKQ
7rTMGI2/rFCUP1+Krs7PHvsWG8HzvepMzH4+pmR3FwodjRB2LqND18wEiQd6
3wZVG8LCpL6spcIUFjXlfut8DZGuld0VGGYGm40CSWrbEpzk3Jb3GKxAfa9y
k2HQEgiG07qTL5sjsvWwov8JD1EuH6QzwRaIVxY0cyQ8+O/hV599aYmyxAPe
B0cM0DH32IcVroJ78Jvjwv0GmN529Ebd96ux1bzlmuOEPnrMnmgfk1ohx9vP
SibXR/qFjCz7QAGsK6UHDVV6SNM8FRq11Br90QEm49l6CJ7xiv/hmTVWimRF
RmZ6eFu6vrb7Rxvcc9/8KueKLp755vuflNsi83xPXqC9Li7mec7afinETcrV
llTqQCjNefe7yA6S0dzttWIdaHqIvZnSDjZDrZyQFm1U37Wr5D+0x3YHhdzP
XxtVDvFHfi50QMk90Y7Ybi4SrKPjo/aIELeLpzMeyoXJ0zoFW+uIKt9LaU1D
WliM27bKQu0Izbie3V1HtNDykLYL/3JCw9wdtZuSg06T7xrarq/B6UdB3L4U
Dq6PyJShUmdMlDq9esDjYJu0eutQgAtutbdmL8vThFAmODGvI0auuyqvyEIT
hnqm0UlxYvw5M7o34ZoG+sL7k2ZfiFFUZ6931UYDj+q3uPhtcIVWpp2QG7lI
10SOzc5Vu+ISlXSmSNW01sDlUPJyNxwsGXBNylDRlfFfqNVyN2yZNgrhKD7R
6fW5ZTOv3TD79+WPXhULdGpOPl2/iaA/JTlC2T5Pd/Lzdo7dJcisuRMm6WS0
/7B5jX4jwWvutaDfOhj9prOMJ2oi+FyS5ex2n9Ho441th5oJ9Be/VvNaGc2Y
HBZNtBHkbmbFrT8xWv3AfXGyk+D8qPeAUMGoQUZf+XQfgcLy190fExjNG9zH
MR0g0JBVBITHMWq6firUfZAg4n6+4yMZo6vfc/kJLwlspeELN6IZXbfX+dvZ
EYLyBq0roeGMRnqf2Dr/D8HtHUG990IYHS/kVZq/IzAqd24XBzMaoyzQ9p4i
iJ1ffrN4I6PHKm42JSsJSOmoPDGA0XyzpzaqGYL6yewVjl6MLj8almY5R2Dm
L9Ms8mD0aveb576MILFg1xh3LaM3MlVnUhcI1vmIGgedGXUeyhor+URw8Sy/
NNiJ0Tof/oZWFQEbns9ucGDUs+hqyQs1QajHq1hbO0ZbPgjZ4iJBc06X5JwN
o/8C1k/QBg==
       "]]}, 
     {RGBColor[0, 0, 1], 
      LineBox[{{0.6834965309233769, 26.21552428353636}, {0.8181671417091729, 
       25.27283000803579}, {1.2155576714030418`, 22.491096300178707`}, {
       1.605152976377521, 19.763929165357354`}, {1.9960953443877552`, 
       17.027332589285713`}}], 
      LineBox[{{2.003904655612245, 16.972667410714287`}, {2.3948211820663112`,
        14.236251725535821`}, {2.822255302678539, 11.244212881250228`}, {
       2.993622448979592, 10.044642857142856`}}], 
      LineBox[{{3.006377551020408, 9.955357142857144}, {3.3918436711734476`, 
       7.257094301785866}, {3.8163002808928117`, 4.285898033750318}, {
       4.21255350262748, 1.5121254816076402`}, {
       4.601011499642759, -1.2070804974993123`}, {
       5.022490598469259, -4.157434189284816}, {
       5.4157663093110635`, -6.910364165177445}, {
       5.84206312196409, -9.894441853748631}, {
       6.260564709897727, -12.823952969284086`}, {
       6.650862909846667, -15.556040368926674`}, {
       7.07418221160683, -18.51927548124781}, {
       7.469298125382297, -21.28508687767608}, {
       7.502363686624828, -21.516545806373795`}}]}, {}}, {{}, {}, {}, {}, {}, \
{}, {}}}, {{}, 
    {Hue[0.67, 0.6, 0.6], PointBox[{{10., 3.}, {3., 10.}}]}, {}}, 
   {Dashing[{Small, Small}], LineBox[{{10, 3}, {3, 10}}]}, 
   InsetBox["\<\"(10, 3)\"\>", {9, 3.2}], 
   InsetBox["\<\"(3, 10)\"\>", {3.3, 9}]},
  AspectRatio->Automatic,
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 20}, {-21.516545806373795`, 26.21552428353636}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.535241830399082*^9, 3.5352419575491037`*^9, 
  3.535241992342771*^9, 3.5352427498627567`*^9, 3.535242843177846*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise", "Subsubsection",
 CellChangeTimes->{{3.5352429410920973`*^9, 3.535242943281633*^9}}],

Cell[TextData[{
 "Graph  the function  Q(x) = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"2", "x"}], 
    RowBox[{"x", " ", "+", " ", "4"}]], TraditionalForm]]],
 " and   its  inverse function Q",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) along with the tangent to the graph of \ny = Q",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "(x) at the point (1, 4) and the tangent to the graph y = Q(x) at the point \
(4, 1). \n"
}], "Text",
 CellChangeTimes->{{3.5352429529516897`*^9, 3.535243077682767*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Working",
WindowSize->{1495, 1048},
WindowMargins->{{24, Automatic}, {Automatic, 0}},
ShowGroupOpener->True,
Magnification->2.,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 104, 1, 120, "Title"],
Cell[686, 25, 163, 3, 42, "Subtitle"],
Cell[852, 30, 1493, 38, 232, "Text"],
Cell[CellGroupData[{
Cell[2370, 72, 204, 3, 144, "Section"],
Cell[CellGroupData[{
Cell[2599, 79, 632, 12, 68, "Subsection",
 CellGroupingRules->{"SectionGrouping", Inherited}],
Cell[3234, 93, 1871, 51, 1616, "Text",
 CellGroupingRules->"NormalGrouping"]
}, Closed]],
Cell[CellGroupData[{
Cell[5142, 149, 418, 6, 48, "Subsection",
 CellGroupingRules->{"SectionGrouping", Inherited}],
Cell[CellGroupData[{
Cell[5585, 159, 730, 14, 592, "Subsubsection"],
Cell[6318, 175, 987, 20, 1040, "Text"],
Cell[7308, 197, 369, 11, 592, "Input"],
Cell[CellGroupData[{
Cell[7702, 212, 272, 7, 592, "Input"],
Cell[7977, 221, 6298, 111, 8288, "Output"]
}, Closed]],
Cell[14290, 335, 2077, 36, 3456, "Text"],
Cell[CellGroupData[{
Cell[16392, 375, 449, 12, 592, "Input"],
Cell[16844, 389, 7802, 139, 8288, "Output"]
}, Closed]],
Cell[24661, 531, 16, 0, 336, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24714, 536, 360, 7, 384, "Subsubsection"],
Cell[25077, 545, 2420, 55, 8512, "Text"],
Cell[CellGroupData[{
Cell[27522, 604, 187, 5, 1536, "Input"],
Cell[27712, 611, 228, 7, 2064, "Output"]
}, Open  ]],
Cell[27955, 621, 263, 8, 1536, "Input"],
Cell[28221, 631, 16, 0, 832, "Text"],
Cell[28240, 633, 16, 0, 832, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[28293, 638, 127, 2, 256, "Subsubsection"],
Cell[28423, 642, 613, 14, 752, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[29085, 662, 469, 7, 48, "Subsection",
 CellGroupingRules->{"SectionGrouping", Inherited}],
Cell[CellGroupData[{
Cell[29579, 673, 480, 7, 384, "Subsubsection"],
Cell[30062, 682, 4599, 138, 5056, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34698, 825, 307, 5, 768, "Subsubsection"],
Cell[35008, 832, 852, 18, 4960, "Text"],
Cell[CellGroupData[{
Cell[35885, 854, 684, 20, 2032, "Input"],
Cell[36572, 876, 10722, 189, 8304, "Output"]
}, Open  ]],
Cell[47309, 1068, 2496, 72, 5680, "Text"],
Cell[CellGroupData[{
Cell[49830, 1144, 749, 23, 2032, "Input"],
Cell[50582, 1169, 6769, 125, 8304, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[57400, 1300, 110, 4, 1184, "Subsubsection"],
Cell[57513, 1306, 678, 18, 2256, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58252, 1331, 206, 3, 144, "Section"],
Cell[CellGroupData[{
Cell[58483, 1338, 219, 3, 68, "Subsection"],
Cell[58705, 1343, 411, 12, 178, "Text"],
Cell[59119, 1357, 313, 10, 196, "Text"],
Cell[59435, 1369, 634, 18, 192, "Text"],
Cell[CellGroupData[{
Cell[60094, 1391, 98, 1, 96, "Subsubsection"],
Cell[60195, 1394, 243, 5, 104, "Text"],
Cell[60441, 1401, 290, 10, 140, "Text"],
Cell[60734, 1413, 648, 17, 178, "Text"],
Cell[61385, 1432, 532, 17, 140, "Text"],
Cell[61920, 1451, 650, 18, 178, "Text"],
Cell[CellGroupData[{
Cell[62595, 1473, 436, 13, 288, "Input"],
Cell[63034, 1488, 292, 9, 210, "Output"]
}, Open  ]],
Cell[63341, 1500, 285, 9, 118, "Text"],
Cell[63629, 1511, 747, 28, 218, "Text"],
Cell[64379, 1541, 1146, 32, 460, "Text"],
Cell[65528, 1575, 1134, 45, 218, "Text"],
Cell[66665, 1622, 1605, 48, 546, "Text"],
Cell[68273, 1672, 614, 25, 208, "Text"],
Cell[68890, 1699, 1341, 39, 326, "Text"],
Cell[CellGroupData[{
Cell[70256, 1742, 849, 27, 270, "Input"],
Cell[71108, 1771, 239, 7, 202, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[71384, 1783, 386, 10, 128, "Input"],
Cell[71773, 1795, 146, 4, 148, "Output"]
}, Closed]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[71980, 1806, 241, 6, 48, "Subsection",
 CellGroupingRules->{"SectionGrouping", Inherited}],
Cell[72224, 1814, 1393, 44, 386, "Text",
 CellGroupingRules->"NormalGrouping"],
Cell[73620, 1860, 16, 0, 104, "Text"],
Cell[CellGroupData[{
Cell[73661, 1864, 100, 1, 96, "Subsubsection"],
Cell[73764, 1867, 770, 22, 272, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[74583, 1895, 323, 10, 53, "Subsection"],
Cell[74909, 1907, 807, 23, 192, "Text"],
Cell[75719, 1932, 393, 14, 186, "Text"],
Cell[76115, 1948, 508, 16, 192, "Text"],
Cell[76626, 1966, 419, 15, 194, "Text"],
Cell[77048, 1983, 375, 10, 178, "Text"],
Cell[CellGroupData[{
Cell[77448, 1997, 102, 1, 96, "Subsubsection"],
Cell[77553, 2000, 112, 1, 104, "Text"],
Cell[77668, 2003, 667, 26, 208, "Text"],
Cell[CellGroupData[{
Cell[78360, 2033, 767, 24, 270, "Input"],
Cell[79130, 2059, 72, 1, 192, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79239, 2065, 187, 4, 148, "Input"],
Cell[79429, 2071, 70, 1, 192, "Output"]
}, Open  ]],
Cell[79514, 2075, 82, 1, 104, "Text"],
Cell[79599, 2078, 16, 0, 104, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79652, 2083, 100, 1, 96, "Subsubsection"],
Cell[79755, 2086, 541, 19, 138, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[80345, 2111, 332, 11, 53, "Subsection"],
Cell[80680, 2124, 495, 11, 112, "Text"],
Cell[81178, 2137, 1409, 42, 190, "Text"],
Cell[82590, 2181, 896, 33, 59, "Text"],
Cell[CellGroupData[{
Cell[83511, 2218, 149, 2, 48, "Subsubsection"],
Cell[83663, 2222, 941, 28, 126, "Text"],
Cell[CellGroupData[{
Cell[84629, 2254, 1445, 41, 187, "Input"],
Cell[86077, 2297, 18498, 315, 572, "Output"]
}, Open  ]],
Cell[104590, 2615, 1290, 40, 126, "Text"],
Cell[CellGroupData[{
Cell[105905, 2659, 121, 2, 74, "Input"],
Cell[106029, 2663, 94, 1, 74, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106160, 2669, 123, 2, 74, "Input"],
Cell[106286, 2673, 93, 1, 74, "Output"]
}, Open  ]],
Cell[106394, 2677, 244, 5, 52, "Text"],
Cell[CellGroupData[{
Cell[106663, 2686, 2787, 81, 307, "Input"],
Cell[109453, 2769, 15749, 274, 936, "Output"]
}, Open  ]],
Cell[125217, 3046, 16, 0, 52, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[125270, 3051, 152, 2, 48, "Subsubsection"],
Cell[125425, 3055, 740, 22, 106, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[126214, 3083, 504, 16, 73, "Subsection"],
Cell[126721, 3101, 1102, 37, 306, "Text"],
Cell[127826, 3140, 1321, 53, 232, "Text"],
Cell[CellGroupData[{
Cell[129172, 3197, 100, 1, 96, "Subsubsection"],
Cell[129275, 3200, 263, 5, 104, "Text"],
Cell[129541, 3207, 789, 31, 208, "Text"],
Cell[130333, 3240, 864, 32, 278, "Text"],
Cell[CellGroupData[{
Cell[131222, 3276, 789, 25, 270, "Input"],
Cell[132014, 3303, 208, 7, 258, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[132259, 3315, 212, 5, 128, "Input"],
Cell[132474, 3322, 206, 7, 258, "Output"]
}, Closed]],
Cell[132695, 3332, 73, 1, 84, "Text"],
Cell[132771, 3335, 1200, 51, 218, "Text"],
Cell[133974, 3388, 1235, 47, 204, "Text"],
Cell[CellGroupData[{
Cell[135234, 3439, 815, 26, 270, "Input"],
Cell[136052, 3467, 227, 8, 244, "Output"]
}, Closed]],
Cell[136294, 3478, 158, 2, 84, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[136489, 3485, 101, 1, 64, "Subsubsection"],
Cell[136593, 3488, 1175, 45, 238, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[137817, 3539, 399, 13, 53, "Subsection"],
Cell[138219, 3554, 165, 3, 104, "Text"],
Cell[138387, 3559, 863, 32, 214, "Text"],
Cell[139253, 3593, 4216, 162, 682, "Text"],
Cell[CellGroupData[{
Cell[143494, 3759, 98, 1, 96, "Subsubsection"],
Cell[143595, 3762, 105, 1, 104, "Text"],
Cell[143703, 3765, 1298, 48, 208, "Text"],
Cell[145004, 3815, 3032, 100, 628, "Text"],
Cell[CellGroupData[{
Cell[148061, 3919, 3423, 103, 810, "Input"],
Cell[151487, 4024, 19496, 334, 1872, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[171032, 4364, 101, 1, 64, "Subsubsection"],
Cell[171136, 4367, 624, 20, 272, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
